# Generated from 'Movies.h'

def FOUR_CHAR_CODE(x): return x
xmlIdentifierUnrecognized = -1
kControllerMinimum = -0xf777
notImplementedMusicOSErr      = -2071
cantSendToSynthesizerOSErr    = -2072
cantReceiveFromSynthesizerOSErr = -2073
illegalVoiceAllocationOSErr   = -2074
illegalPartOSErr              = -2075
illegalChannelOSErr           = -2076
illegalKnobOSErr              = -2077
illegalKnobValueOSErr         = -2078
illegalInstrumentOSErr        = -2079
illegalControllerOSErr        = -2080
midiManagerAbsentOSErr        = -2081
synthesizerNotRespondingOSErr = -2082
synthesizerOSErr              = -2083
illegalNoteChannelOSErr       = -2084
noteChannelNotAllocatedOSErr  = -2085
tunePlayerFullOSErr           = -2086
tuneParseOSErr                = -2087
MovieFileType = FOUR_CHAR_CODE('MooV')
MovieScrapType = FOUR_CHAR_CODE('moov')
MovieResourceType = FOUR_CHAR_CODE('moov')
MovieForwardPointerResourceType = FOUR_CHAR_CODE('fore')
MovieBackwardPointerResourceType = FOUR_CHAR_CODE('back')
MovieResourceAtomType = FOUR_CHAR_CODE('moov')
MovieDataAtomType = FOUR_CHAR_CODE('mdat')
FreeAtomType = FOUR_CHAR_CODE('free')
SkipAtomType = FOUR_CHAR_CODE('skip')
WideAtomPlaceholderType = FOUR_CHAR_CODE('wide')
MediaHandlerType = FOUR_CHAR_CODE('mhlr')
DataHandlerType = FOUR_CHAR_CODE('dhlr')
VideoMediaType = FOUR_CHAR_CODE('vide')
SoundMediaType = FOUR_CHAR_CODE('soun')
TextMediaType = FOUR_CHAR_CODE('text')
BaseMediaType = FOUR_CHAR_CODE('gnrc')
MPEGMediaType = FOUR_CHAR_CODE('MPEG')
MusicMediaType = FOUR_CHAR_CODE('musi')
TimeCodeMediaType = FOUR_CHAR_CODE('tmcd')
SpriteMediaType = FOUR_CHAR_CODE('sprt')
FlashMediaType = FOUR_CHAR_CODE('flsh')
MovieMediaType = FOUR_CHAR_CODE('moov')
TweenMediaType = FOUR_CHAR_CODE('twen')
ThreeDeeMediaType = FOUR_CHAR_CODE('qd3d')
SkinMediaType = FOUR_CHAR_CODE('skin')
HandleDataHandlerSubType = FOUR_CHAR_CODE('hndl')
PointerDataHandlerSubType = FOUR_CHAR_CODE('ptr ')
NullDataHandlerSubType = FOUR_CHAR_CODE('null')
ResourceDataHandlerSubType = FOUR_CHAR_CODE('rsrc')
URLDataHandlerSubType = FOUR_CHAR_CODE('url ')
WiredActionHandlerType = FOUR_CHAR_CODE('wire')
VisualMediaCharacteristic = FOUR_CHAR_CODE('eyes')
AudioMediaCharacteristic = FOUR_CHAR_CODE('ears')
kCharacteristicCanSendVideo = FOUR_CHAR_CODE('vsnd')
kCharacteristicProvidesActions = FOUR_CHAR_CODE('actn')
kCharacteristicNonLinear = FOUR_CHAR_CODE('nonl')
kCharacteristicCanStep = FOUR_CHAR_CODE('step')
kCharacteristicHasNoDuration = FOUR_CHAR_CODE('noti')
kCharacteristicHasSkinData = FOUR_CHAR_CODE('skin')
kCharacteristicProvidesKeyFocus = FOUR_CHAR_CODE('keyf')
kUserDataMovieControllerType = FOUR_CHAR_CODE('ctyp')
kUserDataName = FOUR_CHAR_CODE('name')
kUserDataTextAlbum = FOUR_CHAR_CODE('\xa9alb')
kUserDataTextArtist = FOUR_CHAR_CODE('\xa9ART')
kUserDataTextAuthor = FOUR_CHAR_CODE('\xa9aut')
kUserDataTextChapter = FOUR_CHAR_CODE('\xa9chp')
kUserDataTextComment = FOUR_CHAR_CODE('\xa9cmt')
kUserDataTextComposer = FOUR_CHAR_CODE('\xa9com')
kUserDataTextCopyright = FOUR_CHAR_CODE('\xa9cpy')
kUserDataTextCreationDate = FOUR_CHAR_CODE('\xa9day')
kUserDataTextDescription = FOUR_CHAR_CODE('\xa9des')
kUserDataTextDirector = FOUR_CHAR_CODE('\xa9dir')
kUserDataTextDisclaimer = FOUR_CHAR_CODE('\xa9dis')
kUserDataTextEncodedBy = FOUR_CHAR_CODE('\xa9enc')
kUserDataTextFullName = FOUR_CHAR_CODE('\xa9nam')
kUserDataTextGenre = FOUR_CHAR_CODE('\xa9gen')
kUserDataTextHostComputer = FOUR_CHAR_CODE('\xa9hst')
kUserDataTextInformation = FOUR_CHAR_CODE('\xa9inf')
kUserDataTextKeywords = FOUR_CHAR_CODE('\xa9key')
kUserDataTextMake = FOUR_CHAR_CODE('\xa9mak')
kUserDataTextModel = FOUR_CHAR_CODE('\xa9mod')
kUserDataTextOriginalArtist = FOUR_CHAR_CODE('\xa9ope')
kUserDataTextOriginalFormat = FOUR_CHAR_CODE('\xa9fmt')
kUserDataTextOriginalSource = FOUR_CHAR_CODE('\xa9src')
kUserDataTextPerformers = FOUR_CHAR_CODE('\xa9prf')
kUserDataTextProducer = FOUR_CHAR_CODE('\xa9prd')
kUserDataTextProduct = FOUR_CHAR_CODE('\xa9PRD')
kUserDataTextSoftware = FOUR_CHAR_CODE('\xa9swr')
kUserDataTextSpecialPlaybackRequirements = FOUR_CHAR_CODE('\xa9req')
kUserDataTextTrack = FOUR_CHAR_CODE('\xa9trk')
kUserDataTextWarning = FOUR_CHAR_CODE('\xa9wrn')
kUserDataTextWriter = FOUR_CHAR_CODE('\xa9wrt')
kUserDataTextURLLink = FOUR_CHAR_CODE('\xa9url')
kUserDataTextEditDate1 = FOUR_CHAR_CODE('\xa9ed1')
kUserDataUnicodeBit = 1L << 7
DoTheRightThing = 0
kQTNetworkStatusNoNetwork = -2
kQTNetworkStatusUncertain = -1
kQTNetworkStatusNotConnected = 0
kQTNetworkStatusConnected = 1
kMusicFlagDontPlay2Soft = 1L << 0
kMusicFlagDontSlaveToMovie = 1L << 1
dfDontDisplay = 1 << 0
dfDontAutoScale = 1 << 1
dfClipToTextBox = 1 << 2
dfUseMovieBGColor = 1 << 3
dfShrinkTextBoxToFit = 1 << 4
dfScrollIn = 1 << 5
dfScrollOut = 1 << 6
dfHorizScroll = 1 << 7
dfReverseScroll = 1 << 8
dfContinuousScroll = 1 << 9
dfFlowHoriz = 1 << 10
dfContinuousKaraoke = 1 << 11
dfDropShadow = 1 << 12
dfAntiAlias = 1 << 13
dfKeyedText = 1 << 14
dfInverseHilite = 1 << 15
dfTextColorHilite = 1 << 16
searchTextDontGoToFoundTime = 1L << 16
searchTextDontHiliteFoundText = 1L << 17
searchTextOneTrackOnly = 1L << 18
searchTextEnabledTracksOnly = 1L << 19
kTextTextHandle = 1
kTextTextPtr = 2
kTextTEStyle = 3
kTextSelection = 4
kTextBackColor = 5
kTextForeColor = 6
kTextFace = 7
kTextFont = 8
kTextSize = 9
kTextAlignment = 10
kTextHilite = 11
kTextDropShadow = 12
kTextDisplayFlags = 13
kTextScroll = 14
kTextRelativeScroll = 15
kTextHyperTextFace = 16
kTextHyperTextColor = 17
kTextKeyEntry = 18
kTextMouseDown = 19
kTextTextBox = 20
kTextEditState = 21
kTextLength = 22
k3DMediaRendererEntry = FOUR_CHAR_CODE('rend')
k3DMediaRendererName = FOUR_CHAR_CODE('name')
k3DMediaRendererCode = FOUR_CHAR_CODE('rcod')
movieProgressOpen = 0
movieProgressUpdatePercent = 1
movieProgressClose = 2
progressOpFlatten = 1
progressOpInsertTrackSegment = 2
progressOpInsertMovieSegment = 3
progressOpPaste = 4
progressOpAddMovieSelection = 5
progressOpCopy = 6
progressOpCut = 7
progressOpLoadMovieIntoRam = 8
progressOpLoadTrackIntoRam = 9
progressOpLoadMediaIntoRam = 10
progressOpImportMovie = 11
progressOpExportMovie = 12
mediaQualityDraft = 0x0000
mediaQualityNormal = 0x0040
mediaQualityBetter = 0x0080
mediaQualityBest = 0x00C0
kQTEventPayloadIsQTList = 1L << 0
kActionMovieSetVolume = 1024
kActionMovieSetRate = 1025
kActionMovieSetLoopingFlags = 1026
kActionMovieGoToTime = 1027
kActionMovieGoToTimeByName = 1028
kActionMovieGoToBeginning = 1029
kActionMovieGoToEnd = 1030
kActionMovieStepForward = 1031
kActionMovieStepBackward = 1032
kActionMovieSetSelection = 1033
kActionMovieSetSelectionByName = 1034
kActionMoviePlaySelection = 1035
kActionMovieSetLanguage = 1036
kActionMovieChanged = 1037
kActionMovieRestartAtTime = 1038
kActionMovieGotoNextChapter = 1039
kActionMovieGotoPreviousChapter = 1040
kActionMovieGotoFirstChapter = 1041
kActionMovieGotoLastChapter = 1042
kActionMovieGotoChapterByIndex = 1043
kActionMovieSetScale = 1044
kActionTrackSetVolume = 2048
kActionTrackSetBalance = 2049
kActionTrackSetEnabled = 2050
kActionTrackSetMatrix = 2051
kActionTrackSetLayer = 2052
kActionTrackSetClip = 2053
kActionTrackSetCursor = 2054
kActionTrackSetGraphicsMode = 2055
kActionTrackSetIdleFrequency = 2056
kActionTrackSetBassTreble = 2057
kActionSpriteSetMatrix = 3072
kActionSpriteSetImageIndex = 3073
kActionSpriteSetVisible = 3074
kActionSpriteSetLayer = 3075
kActionSpriteSetGraphicsMode = 3076
kActionSpritePassMouseToCodec = 3078
kActionSpriteClickOnCodec = 3079
kActionSpriteTranslate = 3080
kActionSpriteScale = 3081
kActionSpriteRotate = 3082
kActionSpriteStretch = 3083
kActionSpriteSetCanBeHitTested = 3094
kActionQTVRSetPanAngle = 4096
kActionQTVRSetTiltAngle = 4097
kActionQTVRSetFieldOfView = 4098
kActionQTVRShowDefaultView = 4099
kActionQTVRGoToNodeID = 4100
kActionQTVREnableHotSpot = 4101
kActionQTVRShowHotSpots = 4102
kActionQTVRTranslateObject = 4103
kActionQTVRSetViewState = 4109
kActionMusicPlayNote = 5120
kActionMusicSetController = 5121
kActionCase = 6144
kActionWhile = 6145
kActionGoToURL = 6146
kActionSendQTEventToSprite = 6147
kActionDebugStr = 6148
kActionPushCurrentTime = 6149
kActionPushCurrentTimeWithLabel = 6150
kActionPopAndGotoTopTime = 6151
kActionPopAndGotoLabeledTime = 6152
kActionStatusString = 6153
kActionSendQTEventToTrackObject = 6154
kActionAddChannelSubscription = 6155
kActionRemoveChannelSubscription = 6156
kActionOpenCustomActionHandler = 6157
kActionDoScript = 6158
kActionDoCompressedActions = 6159
kActionSendAppMessage = 6160
kActionLoadComponent = 6161
kActionSetFocus = 6162
kActionDontPassKeyEvent = 6163
kActionSetRandomSeed = 6164
kActionSpriteTrackSetVariable = 7168
kActionSpriteTrackNewSprite = 7169
kActionSpriteTrackDisposeSprite = 7170
kActionSpriteTrackSetVariableToString = 7171
kActionSpriteTrackConcatVariables = 7172
kActionSpriteTrackSetVariableToMovieURL = 7173
kActionSpriteTrackSetVariableToMovieBaseURL = 7174
kActionSpriteTrackSetAllSpritesHitTestingMode = 7181
kActionSpriteTrackNewImage = 7182
kActionSpriteTrackDisposeImage = 7183
kActionApplicationNumberAndString = 8192
kActionQD3DNamedObjectTranslateTo = 9216
kActionQD3DNamedObjectScaleTo = 9217
kActionQD3DNamedObjectRotateTo = 9218
kActionFlashTrackSetPan = 10240
kActionFlashTrackSetZoom = 10241
kActionFlashTrackSetZoomRect = 10242
kActionFlashTrackGotoFrameNumber = 10243
kActionFlashTrackGotoFrameLabel = 10244
kActionFlashTrackSetFlashVariable = 10245
kActionFlashTrackDoButtonActions = 10246
kActionMovieTrackAddChildMovie = 11264
kActionMovieTrackLoadChildMovie = 11265
kActionMovieTrackLoadChildMovieWithQTListParams = 11266
kActionTextTrackPasteText = 12288
kActionTextTrackSetTextBox = 12291
kActionTextTrackSetTextStyle = 12292
kActionTextTrackSetSelection = 12293
kActionTextTrackSetBackgroundColor = 12294
kActionTextTrackSetForegroundColor = 12295
kActionTextTrackSetFace = 12296
kActionTextTrackSetFont = 12297
kActionTextTrackSetSize = 12298
kActionTextTrackSetAlignment = 12299
kActionTextTrackSetHilite = 12300
kActionTextTrackSetDropShadow = 12301
kActionTextTrackSetDisplayFlags = 12302
kActionTextTrackSetScroll = 12303
kActionTextTrackRelativeScroll = 12304
kActionTextTrackFindText = 12305
kActionTextTrackSetHyperTextFace = 12306
kActionTextTrackSetHyperTextColor = 12307
kActionTextTrackKeyEntry = 12308
kActionTextTrackMouseDown = 12309
kActionTextTrackSetEditable = 12310
kActionListAddElement = 13312
kActionListRemoveElements = 13313
kActionListSetElementValue = 13314
kActionListPasteFromXML = 13315
kActionListSetMatchingFromXML = 13316
kActionListSetFromURL = 13317
kActionListExchangeLists = 13318
kActionListServerQuery = 13319
kOperandExpression = 1
kOperandConstant = 2
kOperandSubscribedToChannel = 3
kOperandUniqueCustomActionHandlerID = 4
kOperandCustomActionHandlerIDIsOpen = 5
kOperandConnectionSpeed = 6
kOperandGMTDay = 7
kOperandGMTMonth = 8
kOperandGMTYear = 9
kOperandGMTHours = 10
kOperandGMTMinutes = 11
kOperandGMTSeconds = 12
kOperandLocalDay = 13
kOperandLocalMonth = 14
kOperandLocalYear = 15
kOperandLocalHours = 16
kOperandLocalMinutes = 17
kOperandLocalSeconds = 18
kOperandRegisteredForQuickTimePro = 19
kOperandPlatformRunningOn = 20
kOperandQuickTimeVersion = 21
kOperandComponentVersion = 22
kOperandOriginalHandlerRefcon = 23
kOperandTicks = 24
kOperandMaxLoadedTimeInMovie = 25
kOperandEventParameter = 26
kOperandFreeMemory = 27
kOperandNetworkStatus = 28
kOperandQuickTimeVersionRegistered = 29
kOperandSystemVersion = 30
kOperandMovieVolume = 1024
kOperandMovieRate = 1025
kOperandMovieIsLooping = 1026
kOperandMovieLoopIsPalindrome = 1027
kOperandMovieTime = 1028
kOperandMovieDuration = 1029
kOperandMovieTimeScale = 1030
kOperandMovieWidth = 1031
kOperandMovieHeight = 1032
kOperandMovieLoadState = 1033
kOperandMovieTrackCount = 1034
kOperandMovieIsActive = 1035
kOperandMovieName = 1036
kOperandMovieID = 1037
kOperandMovieChapterCount = 1038
kOperandMovieChapterIndex = 1039
kOperandMovieChapterName = 1040
kOperandMovieChapterNameByIndex = 1041
kOperandMovieChapterIndexByName = 1042
kOperandMovieAnnotation = 1043
kOperandMovieConnectionFlags = 1044
kOperandMovieConnectionString = 1045
kOperandTrackVolume = 2048
kOperandTrackBalance = 2049
kOperandTrackEnabled = 2050
kOperandTrackLayer = 2051
kOperandTrackWidth = 2052
kOperandTrackHeight = 2053
kOperandTrackDuration = 2054
kOperandTrackName = 2055
kOperandTrackID = 2056
kOperandTrackIdleFrequency = 2057
kOperandTrackBass = 2058
kOperandTrackTreble = 2059
kOperandSpriteBoundsLeft = 3072
kOperandSpriteBoundsTop = 3073
kOperandSpriteBoundsRight = 3074
kOperandSpriteBoundsBottom = 3075
kOperandSpriteImageIndex = 3076
kOperandSpriteVisible = 3077
kOperandSpriteLayer = 3078
kOperandSpriteTrackVariable = 3079
kOperandSpriteTrackNumSprites = 3080
kOperandSpriteTrackNumImages = 3081
kOperandSpriteID = 3082
kOperandSpriteIndex = 3083
kOperandSpriteFirstCornerX = 3084
kOperandSpriteFirstCornerY = 3085
kOperandSpriteSecondCornerX = 3086
kOperandSpriteSecondCornerY = 3087
kOperandSpriteThirdCornerX = 3088
kOperandSpriteThirdCornerY = 3089
kOperandSpriteFourthCornerX = 3090
kOperandSpriteFourthCornerY = 3091
kOperandSpriteImageRegistrationPointX = 3092
kOperandSpriteImageRegistrationPointY = 3093
kOperandSpriteTrackSpriteIDAtPoint = 3094
kOperandSpriteName = 3095
kOperandSpriteCanBeHitTested = 3105
kOperandSpriteTrackAllSpritesHitTestingMode = 3106
kOperandSpriteTrackImageIDByIndex = 3107
kOperandSpriteTrackImageIndexByID = 3108
kOperandQTVRPanAngle = 4096
kOperandQTVRTiltAngle = 4097
kOperandQTVRFieldOfView = 4098
kOperandQTVRNodeID = 4099
kOperandQTVRHotSpotsVisible = 4100
kOperandQTVRViewCenterH = 4101
kOperandQTVRViewCenterV = 4102
kOperandQTVRViewStateCount = 4103
kOperandQTVRViewState = 4104
kOperandMouseLocalHLoc = 5120
kOperandMouseLocalVLoc = 5121
kOperandKeyIsDown = 5122
kOperandRandom = 5123
kOperandCanHaveFocus = 5124
kOperandHasFocus = 5125
kOperandTextTrackEditable = 6144
kOperandTextTrackCopyText = 6145
kOperandTextTrackStartSelection = 6146
kOperandTextTrackEndSelection = 6147
kOperandTextTrackTextBoxLeft = 6148
kOperandTextTrackTextBoxTop = 6149
kOperandTextTrackTextBoxRight = 6150
kOperandTextTrackTextBoxBottom = 6151
kOperandTextTrackTextLength = 6152
kOperandListCountElements = 7168
kOperandListGetElementPathByIndex = 7169
kOperandListGetElementValue = 7170
kOperandListCopyToXML = 7171
kOperandSin = 8192
kOperandCos = 8193
kOperandTan = 8194
kOperandATan = 8195
kOperandATan2 = 8196
kOperandDegreesToRadians = 8197
kOperandRadiansToDegrees = 8198
kOperandSquareRoot = 8199
kOperandExponent = 8200
kOperandLog = 8201
kOperandFlashTrackVariable = 9216
kOperandStringLength = 10240
kOperandStringCompare = 10241
kOperandStringSubString = 10242
kOperandStringConcat = 10243
kFirstMovieAction = kActionMovieSetVolume
kLastMovieAction = kActionMovieSetScale
kFirstTrackAction = kActionTrackSetVolume
kLastTrackAction = kActionTrackSetBassTreble
kFirstSpriteAction = kActionSpriteSetMatrix
kLastSpriteAction = kActionSpriteSetCanBeHitTested
kFirstQTVRAction = kActionQTVRSetPanAngle
kLastQTVRAction = kActionQTVRSetViewState
kFirstMusicAction = kActionMusicPlayNote
kLastMusicAction = kActionMusicSetController
kFirstSystemAction = kActionCase
kLastSystemAction = kActionSetRandomSeed
kFirstSpriteTrackAction = kActionSpriteTrackSetVariable
kLastSpriteTrackAction = kActionSpriteTrackDisposeImage
kFirstApplicationAction = kActionApplicationNumberAndString
kLastApplicationAction = kActionApplicationNumberAndString
kFirstQD3DNamedObjectAction = kActionQD3DNamedObjectTranslateTo
kLastQD3DNamedObjectAction = kActionQD3DNamedObjectRotateTo
kFirstFlashTrackAction = kActionFlashTrackSetPan
kLastFlashTrackAction = kActionFlashTrackDoButtonActions
kFirstMovieTrackAction = kActionMovieTrackAddChildMovie
kLastMovieTrackAction = kActionMovieTrackLoadChildMovieWithQTListParams
kFirstTextTrackAction = kActionTextTrackPasteText
kLastTextTrackAction = kActionTextTrackSetEditable
kFirstMultiTargetAction = kActionListAddElement
kLastMultiTargetAction = kActionListServerQuery
kFirstAction = kFirstMovieAction
kLastAction = kLastMultiTargetAction
kTargetMovie = FOUR_CHAR_CODE('moov')
kTargetMovieName = FOUR_CHAR_CODE('mona')
kTargetMovieID = FOUR_CHAR_CODE('moid')
kTargetRootMovie = FOUR_CHAR_CODE('moro')
kTargetParentMovie = FOUR_CHAR_CODE('mopa')
kTargetChildMovieTrackName = FOUR_CHAR_CODE('motn')
kTargetChildMovieTrackID = FOUR_CHAR_CODE('moti')
kTargetChildMovieTrackIndex = FOUR_CHAR_CODE('motx')
kTargetChildMovieMovieName = FOUR_CHAR_CODE('momn')
kTargetChildMovieMovieID = FOUR_CHAR_CODE('momi')
kTargetTrackName = FOUR_CHAR_CODE('trna')
kTargetTrackID = FOUR_CHAR_CODE('trid')
kTargetTrackType = FOUR_CHAR_CODE('trty')
kTargetTrackIndex = FOUR_CHAR_CODE('trin')
kTargetSpriteName = FOUR_CHAR_CODE('spna')
kTargetSpriteID = FOUR_CHAR_CODE('spid')
kTargetSpriteIndex = FOUR_CHAR_CODE('spin')
kTargetQD3DNamedObjectName = FOUR_CHAR_CODE('nana')
kTargetCurrentQTEventParams = FOUR_CHAR_CODE('evpa')
kQTEventType = FOUR_CHAR_CODE('evnt')
kAction = FOUR_CHAR_CODE('actn')
kWhichAction = FOUR_CHAR_CODE('whic')
kActionParameter = FOUR_CHAR_CODE('parm')
kActionTarget = FOUR_CHAR_CODE('targ')
kActionFlags = FOUR_CHAR_CODE('flag')
kActionParameterMinValue = FOUR_CHAR_CODE('minv')
kActionParameterMaxValue = FOUR_CHAR_CODE('maxv')
kActionListAtomType = FOUR_CHAR_CODE('list')
kExpressionContainerAtomType = FOUR_CHAR_CODE('expr')
kConditionalAtomType = FOUR_CHAR_CODE('test')
kOperatorAtomType = FOUR_CHAR_CODE('oper')
kOperandAtomType = FOUR_CHAR_CODE('oprn')
kCommentAtomType = FOUR_CHAR_CODE('why ')
kCustomActionHandler = FOUR_CHAR_CODE('cust')
kCustomHandlerID = FOUR_CHAR_CODE('id  ')
kCustomHandlerDesc = FOUR_CHAR_CODE('desc')
kQTEventRecordAtomType = FOUR_CHAR_CODE('erec')
kQTEventMouseClick = FOUR_CHAR_CODE('clik')
kQTEventMouseClickEnd = FOUR_CHAR_CODE('cend')
kQTEventMouseClickEndTriggerButton = FOUR_CHAR_CODE('trig')
kQTEventMouseEnter = FOUR_CHAR_CODE('entr')
kQTEventMouseExit = FOUR_CHAR_CODE('exit')
kQTEventMouseMoved = FOUR_CHAR_CODE('move')
kQTEventFrameLoaded = FOUR_CHAR_CODE('fram')
kQTEventIdle = FOUR_CHAR_CODE('idle')
kQTEventKey = FOUR_CHAR_CODE('key ')
kQTEventMovieLoaded = FOUR_CHAR_CODE('load')
kQTEventRequestToModifyMovie = FOUR_CHAR_CODE('reqm')
kQTEventListReceived = FOUR_CHAR_CODE('list')
kQTEventKeyUp = FOUR_CHAR_CODE('keyU')
kActionFlagActionIsDelta = 1L << 1
kActionFlagParameterWrapsAround = 1L << 2
kActionFlagActionIsToggle = 1L << 3
kStatusStringIsURLLink = 1L << 1
kStatusStringIsStreamingStatus = 1L << 2
kStatusHasCodeNumber = 1L << 3
kStatusIsError = 1L << 4
kScriptIsUnknownType = 1L << 0
kScriptIsJavaScript = 1L << 1
kScriptIsLingoEvent = 1L << 2
kScriptIsVBEvent = 1L << 3
kScriptIsProjectorCommand = 1L << 4
kScriptIsAppleScript = 1L << 5
kQTRegistrationDialogTimeOutFlag = 1 << 0
kQTRegistrationDialogShowDialog = 1 << 1
kQTRegistrationDialogForceDialog = 1 << 2
kOperatorAdd = FOUR_CHAR_CODE('add ')
kOperatorSubtract = FOUR_CHAR_CODE('sub ')
kOperatorMultiply = FOUR_CHAR_CODE('mult')
kOperatorDivide = FOUR_CHAR_CODE('div ')
kOperatorOr = FOUR_CHAR_CODE('or  ')
kOperatorAnd = FOUR_CHAR_CODE('and ')
kOperatorNot = FOUR_CHAR_CODE('not ')
kOperatorLessThan = FOUR_CHAR_CODE('<   ')
kOperatorLessThanEqualTo = FOUR_CHAR_CODE('<=  ')
kOperatorEqualTo = FOUR_CHAR_CODE('=   ')
kOperatorNotEqualTo = FOUR_CHAR_CODE('!=  ')
kOperatorGreaterThan = FOUR_CHAR_CODE('>   ')
kOperatorGreaterThanEqualTo = FOUR_CHAR_CODE('>=  ')
kOperatorModulo = FOUR_CHAR_CODE('mod ')
kOperatorIntegerDivide = FOUR_CHAR_CODE('idiv')
kOperatorAbsoluteValue = FOUR_CHAR_CODE('abs ')
kOperatorNegate = FOUR_CHAR_CODE('neg ')
kPlatformMacintosh = 1
kPlatformWindows = 2
kSystemIsWindows9x = 0x00010000
kSystemIsWindowsNT = 0x00020000
kMediaPropertyNonLinearAtomType = FOUR_CHAR_CODE('nonl')
kMediaPropertyHasActions = 105
loopTimeBase = 1
palindromeLoopTimeBase = 2
maintainTimeBaseZero = 4
triggerTimeFwd = 0x0001
triggerTimeBwd = 0x0002
triggerTimeEither = 0x0003
triggerRateLT = 0x0004
triggerRateGT = 0x0008
triggerRateEqual = 0x0010
triggerRateLTE = triggerRateLT | triggerRateEqual
triggerRateGTE = triggerRateGT | triggerRateEqual
triggerRateNotEqual = triggerRateGT | triggerRateEqual | triggerRateLT
triggerRateChange = 0
triggerAtStart = 0x0001
triggerAtStop = 0x0002
timeBaseBeforeStartTime = 1
timeBaseAfterStopTime = 2
callBackAtTime = 1
callBackAtRate = 2
callBackAtTimeJump = 3
callBackAtExtremes = 4
callBackAtTimeBaseDisposed = 5
callBackAtInterrupt = 0x8000
callBackAtDeferredTask = 0x4000
qtcbNeedsRateChanges = 1
qtcbNeedsTimeChanges = 2
qtcbNeedsStartStopChanges = 4
keepInRam = 1 << 0
unkeepInRam = 1 << 1
flushFromRam = 1 << 2
loadForwardTrackEdits = 1 << 3
loadBackwardTrackEdits = 1 << 4
newMovieActive = 1 << 0
newMovieDontResolveDataRefs = 1 << 1
newMovieDontAskUnresolvedDataRefs = 1 << 2
newMovieDontAutoAlternates = 1 << 3
newMovieDontUpdateForeBackPointers = 1 << 4
newMovieDontAutoUpdateClock = 1 << 5
newMovieAsyncOK = 1 << 8
newMovieIdleImportOK = 1 << 10
newMovieDontInteractWithUser = 1 << 11
trackUsageInMovie = 1 << 1
trackUsageInPreview = 1 << 2
trackUsageInPoster = 1 << 3
mediaSampleNotSync = 1 << 0
mediaSampleShadowSync = 1 << 1
pasteInParallel = 1 << 0
showUserSettingsDialog = 1 << 1
movieToFileOnlyExport = 1 << 2
movieFileSpecValid = 1 << 3
nextTimeMediaSample = 1 << 0
nextTimeMediaEdit = 1 << 1
nextTimeTrackEdit = 1 << 2
nextTimeSyncSample = 1 << 3
nextTimeStep = 1 << 4
nextTimeEdgeOK = 1 << 14
nextTimeIgnoreActiveSegment = 1 << 15
createMovieFileDeleteCurFile = 1L << 31
createMovieFileDontCreateMovie = 1L << 30
createMovieFileDontOpenFile = 1L << 29
createMovieFileDontCreateResFile = 1L << 28
flattenAddMovieToDataFork = 1L << 0
flattenActiveTracksOnly = 1L << 2
flattenDontInterleaveFlatten = 1L << 3
flattenFSSpecPtrIsDataRefRecordPtr = 1L << 4
flattenCompressMovieResource = 1L << 5
flattenForceMovieResourceBeforeMovieData = 1L << 6
movieInDataForkResID = -1
mcTopLeftMovie = 1 << 0
mcScaleMovieToFit = 1 << 1
mcWithBadge = 1 << 2
mcNotVisible = 1 << 3
mcWithFrame = 1 << 4
movieScrapDontZeroScrap = 1 << 0
movieScrapOnlyPutMovie = 1 << 1
dataRefSelfReference = 1 << 0
dataRefWasNotResolved = 1 << 1
kMovieAnchorDataRefIsDefault = 1 << 0
hintsScrubMode = 1 << 0
hintsLoop = 1 << 1
hintsDontPurge = 1 << 2
hintsUseScreenBuffer = 1 << 5
hintsAllowInterlace = 1 << 6
hintsUseSoundInterp = 1 << 7
hintsHighQuality = 1 << 8
hintsPalindrome = 1 << 9
hintsInactive = 1 << 11
hintsOffscreen = 1 << 12
hintsDontDraw = 1 << 13
hintsAllowBlacklining = 1 << 14
hintsDontUseVideoOverlaySurface = 1 << 16
hintsIgnoreBandwidthRestrictions = 1 << 17
hintsPlayingEveryFrame = 1 << 18
hintsAllowDynamicResize = 1 << 19
hintsSingleField = 1 << 20
hintsNoRenderingTimeOut = 1 << 21
hintsFlushVideoInsteadOfDirtying = 1 << 22
hintsEnableSubPixelPositioning = 1L << 23
mediaHandlerFlagBaseClient = 1
movieTrackMediaType = 1 << 0
movieTrackCharacteristic = 1 << 1
movieTrackEnabledOnly = 1 << 2
kMovieControlOptionHideController = (1L << 0)
kMovieControlOptionLocateTopLeft = (1L << 1)
kMovieControlOptionEnableEditing = (1L << 2)
kMovieControlOptionHandleEditingHI = (1L << 3)
kMovieControlOptionSetKeysEnabled = (1L << 4)
kMovieControlOptionManuallyIdled = (1L << 5)
kMovieControlDataMovieController = FOUR_CHAR_CODE('mc  ')
kMovieControlDataMovie = FOUR_CHAR_CODE('moov')
kMovieControlDataManualIdling = FOUR_CHAR_CODE('manu')
movieDrawingCallWhenChanged = 0
movieDrawingCallAlways = 1
kQTCloneShareSamples = 1 << 0
kQTCloneDontCopyEdits = 1 << 1
kGetMovieImporterValidateToFind = 1L << 0
kGetMovieImporterAllowNewFile = 1L << 1
kGetMovieImporterDontConsiderGraphicsImporters = 1L << 2
kGetMovieImporterDontConsiderFileOnlyImporters = 1L << 6
kGetMovieImporterAutoImportOnly = 1L << 10
kQTGetMIMETypeInfoIsQuickTimeMovieType = FOUR_CHAR_CODE('moov')
kQTGetMIMETypeInfoIsUnhelpfulType = FOUR_CHAR_CODE('dumb')
kQTCopyUserDataReplace = FOUR_CHAR_CODE('rplc')
kQTCopyUserDataMerge = FOUR_CHAR_CODE('merg')
kMovieLoadStateError = -1L
kMovieLoadStateLoading = 1000
kMovieLoadStateLoaded = 2000
kMovieLoadStatePlayable = 10000
kMovieLoadStatePlaythroughOK = 20000
kMovieLoadStateComplete = 100000L
kQTDontUseDataToFindImporter = 1L << 0
kQTDontLookForMovieImporterIfGraphicsImporterFound = 1L << 1
kQTAllowOpeningStillImagesAsMovies = 1L << 2
kQTAllowImportersThatWouldCreateNewFile = 1L << 3
kQTAllowAggressiveImporters = 1L << 4
preloadAlways = 1L << 0
preloadOnlyIfEnabled = 1L << 1
fullScreenHideCursor = 1L << 0
fullScreenAllowEvents = 1L << 1
fullScreenDontChangeMenuBar = 1L << 2
fullScreenPreflightSize = 1L << 3
movieExecuteWiredActionDontExecute = 1L << 0
kRefConNavigationNext = 0
kRefConNavigationPrevious = 1
kRefConPropertyCanHaveFocus = 1
kRefConPropertyHasFocus = 2
kTrackFocusCanEditFlag = FOUR_CHAR_CODE('kedt')
kTrackDefaultFocusFlags = FOUR_CHAR_CODE('kfoc')
kTrackFocusDefaultRefcon = FOUR_CHAR_CODE('kref')
kTrackFocusOn = 1
kTrackHandlesTabs = 2
kFlashTrackPropertyAcceptAllClicks = FOUR_CHAR_CODE('clik')
kBackgroundSpriteLayerNum = 32767
kSpritePropertyMatrix = 1
kSpritePropertyImageDescription = 2
kSpritePropertyImageDataPtr = 3
kSpritePropertyVisible = 4
kSpritePropertyLayer = 5
kSpritePropertyGraphicsMode = 6
kSpritePropertyImageDataSize = 7
kSpritePropertyActionHandlingSpriteID = 8
kSpritePropertyCanBeHitTested = 9
kSpritePropertyImageIndex = 100
kSpriteTrackPropertyBackgroundColor = 101
kSpriteTrackPropertyOffscreenBitDepth = 102
kSpriteTrackPropertySampleFormat = 103
kSpriteTrackPropertyScaleSpritesToScaleWorld = 104
kSpriteTrackPropertyHasActions = 105
kSpriteTrackPropertyVisible = 106
kSpriteTrackPropertyQTIdleEventsFrequency = 107
kSpriteTrackPropertyAllSpritesHitTestingMode = 108
kSpriteTrackPropertyPreferredDepthInterpretationMode = 109
kSpriteImagePropertyRegistrationPoint = 1000
kSpriteImagePropertyGroupID = 1001
kSpriteTrackPreferredDepthCompatibilityMode = 0
kSpriteTrackPreferredDepthModernMode = 1
kSpriteHitTestUseSpritesOwnPropertiesMode = 0
kSpriteHitTestTreatAllSpritesAsHitTestableMode = 1
kSpriteHitTestTreatAllSpritesAsNotHitTestableMode = 2
kNoQTIdleEvents = -1
kGetSpriteWorldInvalidRegionAndLeaveIntact = -1L
kGetSpriteWorldInvalidRegionAndThenSetEmpty = -2L
kOnlyDrawToSpriteWorld = 1L << 0
kSpriteWorldPreflight = 1L << 1
kSpriteWorldDidDraw = 1L << 0
kSpriteWorldNeedsToDraw = 1L << 1
kKeyFrameAndSingleOverride = 1L << 1
kKeyFrameAndAllOverrides = 1L << 2
kScaleSpritesToScaleWorld = 1L << 1
kSpriteWorldHighQuality = 1L << 2
kSpriteWorldDontAutoInvalidate = 1L << 3
kSpriteWorldInvisible = 1L << 4
kSpriteWorldDirtyInsteadOfFlush = 1L << 5
kParentAtomIsContainer = 0
kTweenRecordNoFlags = 0
kTweenRecordIsAtInterruptTime = 0x00000001
kEffectNameAtom = FOUR_CHAR_CODE('name')
kEffectTypeAtom = FOUR_CHAR_CODE('type')
kEffectManufacturerAtom = FOUR_CHAR_CODE('manu')
pdActionConfirmDialog = 1
pdActionSetAppleMenu = 2
pdActionSetEditMenu = 3
pdActionGetDialogValues = 4
pdActionSetPreviewUserItem = 5
pdActionSetPreviewPicture = 6
pdActionSetColorPickerEventProc = 7
pdActionSetDialogTitle = 8
pdActionGetSubPanelMenu = 9
pdActionActivateSubPanel = 10
pdActionConductStopAlert = 11
pdActionModelessCallback = 12
pdActionFetchPreview = 13
pdActionSetDialogSettings = 14
pdActionGetDialogSettings = 15
pdActionGetNextSample = 16
pdActionGetPreviousSample = 17
pdActionCompactSample = 18
pdActionSetEditCallout = 19
pdActionSetSampleTime = 20
pdActionDoEditCommand = 21
pdActionGetSubPanelMenuValue = 22
pdActionCustomNewControl = 23
pdActionCustomDisposeControl = 24
pdActionCustomPositionControl = 25
pdActionCustomShowHideControl = 26
pdActionCustomHandleEvent = 27
pdActionCustomSetFocus = 28
pdActionCustomSetEditMenu = 29
pdActionCustomSetPreviewPicture = 30
pdActionCustomSetEditCallout = 31
pdActionCustomGetEnableValue = 32
pdActionCustomSetSampleTime = 33
pdActionCustomGetValue = 34
pdActionCustomDoEditCommand = 35
pdSampleTimeDisplayOptionsNone = 0x00000000
pdActionFocusOff = 0
pdActionFocusFirst = 1
pdActionFocusLast = 2
pdActionFocusForward = 3
pdActionFocusBackward = 4
elOptionsIncludeNoneInList = 0x00000001
pdOptionsCollectOneValue = 0x00000001
pdOptionsAllowOptionalInterpolations = 0x00000002
pdOptionsModalDialogBox = 0x00000004
pdOptionsEditCurrentEffectOnly = 0x00000008
pdOptionsHidePreview = 0x00000010
effectIsRealtime = 0
kAccessKeyAtomType = FOUR_CHAR_CODE('acky')
kAccessKeySystemFlag = 1L << 0
ConnectionSpeedPrefsType = FOUR_CHAR_CODE('cspd')
BandwidthManagementPrefsType = FOUR_CHAR_CODE('bwmg')
kQTIdlePriority = 10
kQTNonRealTimePriority = 20
kQTRealTimeSharedPriority = 25
kQTRealTimePriority = 30
kQTBandwidthNotifyNeedToStop = 1L << 0
kQTBandwidthNotifyGoodToGo = 1L << 1
kQTBandwidthChangeRequest = 1L << 2
kQTBandwidthQueueRequest = 1L << 3
kQTBandwidthScheduledRequest = 1L << 4
kQTBandwidthVoluntaryRelease = 1L << 5
kITextRemoveEverythingBut = 0 << 1
kITextRemoveLeaveSuggestedAlternate = 1 << 1
kITextAtomType = FOUR_CHAR_CODE('itxt')
kITextStringAtomType = FOUR_CHAR_CODE('text')
kQTParseTextHREFText = FOUR_CHAR_CODE('text')
kQTParseTextHREFBaseURL = FOUR_CHAR_CODE('burl')
kQTParseTextHREFClickPoint = FOUR_CHAR_CODE('clik')
kQTParseTextHREFUseAltDelim = FOUR_CHAR_CODE('altd')
kQTParseTextHREFDelimiter = FOUR_CHAR_CODE('delm')
kQTParseTextHREFRecomposeHREF = FOUR_CHAR_CODE('rhrf')
kQTParseTextHREFURL = FOUR_CHAR_CODE('url ')
kQTParseTextHREFTarget = FOUR_CHAR_CODE('targ')
kQTParseTextHREFChapter = FOUR_CHAR_CODE('chap')
kQTParseTextHREFIsAutoHREF = FOUR_CHAR_CODE('auto')
kQTParseTextHREFIsServerMap = FOUR_CHAR_CODE('smap')
kQTParseTextHREFHREF = FOUR_CHAR_CODE('href')
kQTParseTextHREFEMBEDArgs = FOUR_CHAR_CODE('mbed')
kTrackReferenceChapterList = FOUR_CHAR_CODE('chap')
kTrackReferenceTimeCode = FOUR_CHAR_CODE('tmcd')
kTrackReferenceModifier = FOUR_CHAR_CODE('ssrc')
kTrackModifierInput = 0x696E
kTrackModifierType = 0x7479
kTrackModifierReference = FOUR_CHAR_CODE('ssrc')
kTrackModifierObjectID = FOUR_CHAR_CODE('obid')
kTrackModifierInputName = FOUR_CHAR_CODE('name')
kInputMapSubInputID = FOUR_CHAR_CODE('subi')
kTrackModifierTypeMatrix = 1
kTrackModifierTypeClip = 2
kTrackModifierTypeGraphicsMode = 5
kTrackModifierTypeVolume = 3
kTrackModifierTypeBalance = 4
kTrackModifierTypeImage = FOUR_CHAR_CODE('vide')
kTrackModifierObjectMatrix = 6
kTrackModifierObjectGraphicsMode = 7
kTrackModifierType3d4x4Matrix = 8
kTrackModifierCameraData = 9
kTrackModifierSoundLocalizationData = 10
kTrackModifierObjectImageIndex = 11
kTrackModifierObjectLayer = 12
kTrackModifierObjectVisible = 13
kTrackModifierAngleAspectCamera = 14
kTrackModifierPanAngle = FOUR_CHAR_CODE('pan ')
kTrackModifierTiltAngle = FOUR_CHAR_CODE('tilt')
kTrackModifierVerticalFieldOfViewAngle = FOUR_CHAR_CODE('fov ')
kTrackModifierObjectQTEventSend = FOUR_CHAR_CODE('evnt')
kTrackModifierObjectCanBeHitTested = 15
kTweenTypeShort = 1
kTweenTypeLong = 2
kTweenTypeFixed = 3
kTweenTypePoint = 4
kTweenTypeQDRect = 5
kTweenTypeQDRegion = 6
kTweenTypeMatrix = 7
kTweenTypeRGBColor = 8
kTweenTypeGraphicsModeWithRGBColor = 9
kTweenTypeQTFloatSingle = 10
kTweenTypeQTFloatDouble = 11
kTweenTypeFixedPoint = 12
kTweenType3dScale = FOUR_CHAR_CODE('3sca')
kTweenType3dTranslate = FOUR_CHAR_CODE('3tra')
kTweenType3dRotate = FOUR_CHAR_CODE('3rot')
kTweenType3dRotateAboutPoint = FOUR_CHAR_CODE('3rap')
kTweenType3dRotateAboutAxis = FOUR_CHAR_CODE('3rax')
kTweenType3dRotateAboutVector = FOUR_CHAR_CODE('3rvc')
kTweenType3dQuaternion = FOUR_CHAR_CODE('3qua')
kTweenType3dMatrix = FOUR_CHAR_CODE('3mat')
kTweenType3dCameraData = FOUR_CHAR_CODE('3cam')
kTweenType3dAngleAspectCameraData = FOUR_CHAR_CODE('3caa')
kTweenType3dSoundLocalizationData = FOUR_CHAR_CODE('3slc')
kTweenTypePathToMatrixTranslation = FOUR_CHAR_CODE('gxmt')
kTweenTypePathToMatrixRotation = FOUR_CHAR_CODE('gxpr')
kTweenTypePathToMatrixTranslationAndRotation = FOUR_CHAR_CODE('gxmr')
kTweenTypePathToFixedPoint = FOUR_CHAR_CODE('gxfp')
kTweenTypePathXtoY = FOUR_CHAR_CODE('gxxy')
kTweenTypePathYtoX = FOUR_CHAR_CODE('gxyx')
kTweenTypeAtomList = FOUR_CHAR_CODE('atom')
kTweenTypePolygon = FOUR_CHAR_CODE('poly')
kTweenTypeMultiMatrix = FOUR_CHAR_CODE('mulm')
kTweenTypeSpin = FOUR_CHAR_CODE('spin')
kTweenType3dMatrixNonLinear = FOUR_CHAR_CODE('3nlr')
kTweenType3dVRObject = FOUR_CHAR_CODE('3vro')
kTweenEntry = FOUR_CHAR_CODE('twen')
kTweenData = FOUR_CHAR_CODE('data')
kTweenType = FOUR_CHAR_CODE('twnt')
kTweenStartOffset = FOUR_CHAR_CODE('twst')
kTweenDuration = FOUR_CHAR_CODE('twdu')
kTweenFlags = FOUR_CHAR_CODE('flag')
kTweenOutputMin = FOUR_CHAR_CODE('omin')
kTweenOutputMax = FOUR_CHAR_CODE('omax')
kTweenSequenceElement = FOUR_CHAR_CODE('seqe')
kTween3dInitialCondition = FOUR_CHAR_CODE('icnd')
kTweenInterpolationID = FOUR_CHAR_CODE('intr')
kTweenRegionData = FOUR_CHAR_CODE('qdrg')
kTweenPictureData = FOUR_CHAR_CODE('PICT')
kListElementType = FOUR_CHAR_CODE('type')
kListElementDataType = FOUR_CHAR_CODE('daty')
kNameAtom = FOUR_CHAR_CODE('name')
kInitialRotationAtom = FOUR_CHAR_CODE('inro')
kNonLinearTweenHeader = FOUR_CHAR_CODE('nlth')
kTweenReturnDelta = 1L << 0
kQTRestrictionClassSave = FOUR_CHAR_CODE('save')
kQTRestrictionSaveDontAddMovieResource = (1L << 0)
kQTRestrictionSaveDontFlatten = (1L << 1)
kQTRestrictionSaveDontExport = (1L << 2)
kQTRestrictionSaveDontExtract = (1L << 3)
kQTRestrictionClassEdit = FOUR_CHAR_CODE('edit')
kQTRestrictionEditDontCopy = (1L << 0)
kQTRestrictionEditDontCut = (1L << 1)
kQTRestrictionEditDontPaste = (1L << 2)
kQTRestrictionEditDontClear = (1L << 3)
kQTRestrictionEditDontModify = (1L << 4)
kQTRestrictionEditDontExtract = (1L << 5)
videoFlagDontLeanAhead = 1L << 0
txtProcDefaultDisplay = 0
txtProcDontDisplay = 1
txtProcDoDisplay = 2
findTextEdgeOK = 1 << 0
findTextCaseSensitive = 1 << 1
findTextReverseSearch = 1 << 2
findTextWrapAround = 1 << 3
findTextUseOffset = 1 << 4
dropShadowOffsetType = FOUR_CHAR_CODE('drpo')
dropShadowTranslucencyType = FOUR_CHAR_CODE('drpt')
spriteHitTestBounds = 1L << 0
spriteHitTestImage = 1L << 1
spriteHitTestInvisibleSprites = 1L << 2
spriteHitTestIsClick = 1L << 3
spriteHitTestLocInDisplayCoordinates = 1L << 4
spriteHitTestTreatAllSpritesAsHitTestable = 1L << 5
kSpriteAtomType = FOUR_CHAR_CODE('sprt')
kSpriteImagesContainerAtomType = FOUR_CHAR_CODE('imct')
kSpriteImageAtomType = FOUR_CHAR_CODE('imag')
kSpriteImageDataAtomType = FOUR_CHAR_CODE('imda')
kSpriteImageDataRefAtomType = FOUR_CHAR_CODE('imre')
kSpriteImageDataRefTypeAtomType = FOUR_CHAR_CODE('imrt')
kSpriteImageGroupIDAtomType = FOUR_CHAR_CODE('imgr')
kSpriteImageRegistrationAtomType = FOUR_CHAR_CODE('imrg')
kSpriteImageDefaultImageIndexAtomType = FOUR_CHAR_CODE('defi')
kSpriteSharedDataAtomType = FOUR_CHAR_CODE('dflt')
kSpriteNameAtomType = FOUR_CHAR_CODE('name')
kSpriteImageNameAtomType = FOUR_CHAR_CODE('name')
kSpriteUsesImageIDsAtomType = FOUR_CHAR_CODE('uses')
kSpriteBehaviorsAtomType = FOUR_CHAR_CODE('beha')
kSpriteImageBehaviorAtomType = FOUR_CHAR_CODE('imag')
kSpriteCursorBehaviorAtomType = FOUR_CHAR_CODE('crsr')
kSpriteStatusStringsBehaviorAtomType = FOUR_CHAR_CODE('sstr')
kSpriteVariablesContainerAtomType = FOUR_CHAR_CODE('vars')
kSpriteStringVariableAtomType = FOUR_CHAR_CODE('strv')
kSpriteFloatingPointVariableAtomType = FOUR_CHAR_CODE('flov')
kMovieMediaDataReference = FOUR_CHAR_CODE('mmdr')
kMovieMediaDefaultDataReferenceID = FOUR_CHAR_CODE('ddri')
kMovieMediaSlaveTime = FOUR_CHAR_CODE('slti')
kMovieMediaSlaveAudio = FOUR_CHAR_CODE('slau')
kMovieMediaSlaveGraphicsMode = FOUR_CHAR_CODE('slgr')
kMovieMediaAutoPlay = FOUR_CHAR_CODE('play')
kMovieMediaLoop = FOUR_CHAR_CODE('loop')
kMovieMediaUseMIMEType = FOUR_CHAR_CODE('mime')
kMovieMediaTitle = FOUR_CHAR_CODE('titl')
kMovieMediaAltText = FOUR_CHAR_CODE('altt')
kMovieMediaClipBegin = FOUR_CHAR_CODE('clpb')
kMovieMediaClipDuration = FOUR_CHAR_CODE('clpd')
kMovieMediaRegionAtom = FOUR_CHAR_CODE('regi')
kMovieMediaSlaveTrackDuration = FOUR_CHAR_CODE('sltr')
kMovieMediaEnableFrameStepping = FOUR_CHAR_CODE('enfs')
kMovieMediaBackgroundColor = FOUR_CHAR_CODE('bkcl')
kMovieMediaPrerollTime = FOUR_CHAR_CODE('prer')
kMovieMediaFitNone = 0
kMovieMediaFitScroll = FOUR_CHAR_CODE('scro')
kMovieMediaFitClipIfNecessary = FOUR_CHAR_CODE('hidd')
kMovieMediaFitFill = FOUR_CHAR_CODE('fill')
kMovieMediaFitMeet = FOUR_CHAR_CODE('meet')
kMovieMediaFitSlice = FOUR_CHAR_CODE('slic')
kMovieMediaSpatialAdjustment = FOUR_CHAR_CODE('fit ')
kMovieMediaRectangleAtom = FOUR_CHAR_CODE('rect')
kMovieMediaTop = FOUR_CHAR_CODE('top ')
kMovieMediaLeft = FOUR_CHAR_CODE('left')
kMovieMediaWidth = FOUR_CHAR_CODE('wd  ')
kMovieMediaHeight = FOUR_CHAR_CODE('ht  ')
kMoviePropertyDuration = FOUR_CHAR_CODE('dura')
kMoviePropertyTimeScale = FOUR_CHAR_CODE('tims')
kMoviePropertyTime = FOUR_CHAR_CODE('timv')
kMoviePropertyNaturalBounds = FOUR_CHAR_CODE('natb')
kMoviePropertyMatrix = FOUR_CHAR_CODE('mtrx')
kMoviePropertyTrackList = FOUR_CHAR_CODE('tlst')
kTrackPropertyMediaType = FOUR_CHAR_CODE('mtyp')
kTrackPropertyInstantiation = FOUR_CHAR_CODE('inst')
MovieControllerComponentType = FOUR_CHAR_CODE('play')
kMovieControllerQTVRFlag = 1 << 0
kMovieControllerDontDisplayToUser = 1 << 1
mcActionIdle = 1
mcActionDraw = 2
mcActionActivate = 3
mcActionDeactivate = 4
mcActionMouseDown = 5
mcActionKey = 6
mcActionPlay = 8
mcActionGoToTime = 12
mcActionSetVolume = 14
mcActionGetVolume = 15
mcActionStep = 18
mcActionSetLooping = 21
mcActionGetLooping = 22
mcActionSetLoopIsPalindrome = 23
mcActionGetLoopIsPalindrome = 24
mcActionSetGrowBoxBounds = 25
mcActionControllerSizeChanged = 26
mcActionSetSelectionBegin = 29
mcActionSetSelectionDuration = 30
mcActionSetKeysEnabled = 32
mcActionGetKeysEnabled = 33
mcActionSetPlaySelection = 34
mcActionGetPlaySelection = 35
mcActionSetUseBadge = 36
mcActionGetUseBadge = 37
mcActionSetFlags = 38
mcActionGetFlags = 39
mcActionSetPlayEveryFrame = 40
mcActionGetPlayEveryFrame = 41
mcActionGetPlayRate = 42
mcActionShowBalloon = 43
mcActionBadgeClick = 44
mcActionMovieClick = 45
mcActionSuspend = 46
mcActionResume = 47
mcActionSetControllerKeysEnabled = 48
mcActionGetTimeSliderRect = 49
mcActionMovieEdited = 50
mcActionGetDragEnabled = 51
mcActionSetDragEnabled = 52
mcActionGetSelectionBegin = 53
mcActionGetSelectionDuration = 54
mcActionPrerollAndPlay = 55
mcActionGetCursorSettingEnabled = 56
mcActionSetCursorSettingEnabled = 57
mcActionSetColorTable = 58
mcActionLinkToURL = 59
mcActionCustomButtonClick = 60
mcActionForceTimeTableUpdate = 61
mcActionSetControllerTimeLimits = 62
mcActionExecuteAllActionsForQTEvent = 63
mcActionExecuteOneActionForQTEvent = 64
mcActionAdjustCursor = 65
mcActionUseTrackForTimeTable = 66
mcActionClickAndHoldPoint = 67
mcActionShowMessageString = 68
mcActionShowStatusString = 69
mcActionGetExternalMovie = 70
mcActionGetChapterTime = 71
mcActionPerformActionList = 72
mcActionEvaluateExpression = 73
mcActionFetchParameterAs = 74
mcActionGetCursorByID = 75
mcActionGetNextURL = 76
mcActionMovieChanged = 77
mcActionDoScript = 78
mcActionRestartAtTime = 79
mcActionGetIndChapter = 80
mcActionLinkToURLExtended = 81
mcActionSetVolumeStep = 82
mcActionAutoPlay = 83
mcActionPauseToBuffer = 84
mcActionAppMessageReceived = 85
mcActionEvaluateExpressionWithType = 89
mcActionGetMovieName = 90
mcActionGetMovieID = 91
mcActionGetMovieActive = 92
mcFlagSuppressMovieFrame = 1 << 0
mcFlagSuppressStepButtons = 1 << 1
mcFlagSuppressSpeakerButton = 1 << 2
mcFlagsUseWindowPalette = 1 << 3
mcFlagsDontInvalidate = 1 << 4
mcFlagsUseCustomButton = 1 << 5
mcPositionDontInvalidate = 1 << 5
kMCIEEnabledButtonPicture = 1
kMCIEDisabledButtonPicture = 2
kMCIEDepressedButtonPicture = 3
kMCIEEnabledSizeBoxPicture = 4
kMCIEDisabledSizeBoxPicture = 5
kMCIEEnabledUnavailableButtonPicture = 6
kMCIEDisabledUnavailableButtonPicture = 7
kMCIESoundSlider = 128
kMCIESoundThumb = 129
kMCIEColorTable = 256
kMCIEIsFlatAppearance = 257
kMCIEDoButtonIconsDropOnDepress = 258
mcInfoUndoAvailable = 1 << 0
mcInfoCutAvailable = 1 << 1
mcInfoCopyAvailable = 1 << 2
mcInfoPasteAvailable = 1 << 3
mcInfoClearAvailable = 1 << 4
mcInfoHasSound = 1 << 5
mcInfoIsPlaying = 1 << 6
mcInfoIsLooping = 1 << 7
mcInfoIsInPalindrome = 1 << 8
mcInfoEditingEnabled = 1 << 9
mcInfoMovieIsInteractive = 1 << 10
mcMenuUndo = 1
mcMenuCut = 3
mcMenuCopy = 4
mcMenuPaste = 5
mcMenuClear = 6
kQTAppMessageSoftwareChanged = 1
kQTAppMessageWindowCloseRequested = 3
kQTAppMessageExitFullScreenRequested = 4
kQTAppMessageDisplayChannels = 5
kQTAppMessageEnterFullScreenRequested = 6
kFetchAsBooleanPtr = 1
kFetchAsShortPtr = 2
kFetchAsLongPtr = 3
kFetchAsMatrixRecordPtr = 4
kFetchAsModifierTrackGraphicsModeRecord = 5
kFetchAsHandle = 6
kFetchAsStr255 = 7
kFetchAsFloatPtr = 8
kFetchAsPointPtr = 9
kFetchAsNewAtomContainer = 10
kFetchAsQTEventRecordPtr = 11
kFetchAsFixedPtr = 12
kFetchAsSetControllerValuePtr = 13
kFetchAsRgnHandle = 14
kFetchAsComponentDescriptionPtr = 15
kFetchAsCString = 16
kQTCursorOpenHand = -19183
kQTCursorClosedHand = -19182
kQTCursorPointingHand = -19181
kQTCursorRightArrow = -19180
kQTCursorLeftArrow = -19179
kQTCursorDownArrow = -19178
kQTCursorUpArrow = -19177
kQTCursorIBeam = -19176
kControllerUnderstandsIdleManagers = 1 << 0
kVideoMediaResetStatisticsSelect = 0x0105
kVideoMediaGetStatisticsSelect = 0x0106
kVideoMediaGetStallCountSelect = 0x010E
kVideoMediaSetCodecParameterSelect = 0x010F
kVideoMediaGetCodecParameterSelect = 0x0110
kTextMediaSetTextProcSelect = 0x0101
kTextMediaAddTextSampleSelect = 0x0102
kTextMediaAddTESampleSelect = 0x0103
kTextMediaAddHiliteSampleSelect = 0x0104
kTextMediaDrawRawSelect = 0x0109
kTextMediaSetTextPropertySelect = 0x010A
kTextMediaRawSetupSelect = 0x010B
kTextMediaRawIdleSelect = 0x010C
kTextMediaGetTextPropertySelect = 0x010D
kTextMediaFindNextTextSelect = 0x0105
kTextMediaHiliteTextSampleSelect = 0x0106
kTextMediaSetTextSampleDataSelect = 0x0107
kSpriteMediaSetPropertySelect = 0x0101
kSpriteMediaGetPropertySelect = 0x0102
kSpriteMediaHitTestSpritesSelect = 0x0103
kSpriteMediaCountSpritesSelect = 0x0104
kSpriteMediaCountImagesSelect = 0x0105
kSpriteMediaGetIndImageDescriptionSelect = 0x0106
kSpriteMediaGetDisplayedSampleNumberSelect = 0x0107
kSpriteMediaGetSpriteNameSelect = 0x0108
kSpriteMediaGetImageNameSelect = 0x0109
kSpriteMediaSetSpritePropertySelect = 0x010A
kSpriteMediaGetSpritePropertySelect = 0x010B
kSpriteMediaHitTestAllSpritesSelect = 0x010C
kSpriteMediaHitTestOneSpriteSelect = 0x010D
kSpriteMediaSpriteIndexToIDSelect = 0x010E
kSpriteMediaSpriteIDToIndexSelect = 0x010F
kSpriteMediaGetSpriteActionsForQTEventSelect = 0x0110
kSpriteMediaSetActionVariableSelect = 0x0111
kSpriteMediaGetActionVariableSelect = 0x0112
kSpriteMediaGetIndImagePropertySelect = 0x0113
kSpriteMediaNewSpriteSelect = 0x0114
kSpriteMediaDisposeSpriteSelect = 0x0115
kSpriteMediaSetActionVariableToStringSelect = 0x0116
kSpriteMediaGetActionVariableAsStringSelect = 0x0117
kSpriteMediaNewImageSelect = 0x011B
kSpriteMediaDisposeImageSelect = 0x011C
kSpriteMediaImageIndexToIDSelect = 0x011D
kSpriteMediaImageIDToIndexSelect = 0x011E
kFlashMediaSetPanSelect = 0x0101
kFlashMediaSetZoomSelect = 0x0102
kFlashMediaSetZoomRectSelect = 0x0103
kFlashMediaGetRefConBoundsSelect = 0x0104
kFlashMediaGetRefConIDSelect = 0x0105
kFlashMediaIDToRefConSelect = 0x0106
kFlashMediaGetDisplayedFrameNumberSelect = 0x0107
kFlashMediaFrameNumberToMovieTimeSelect = 0x0108
kFlashMediaFrameLabelToMovieTimeSelect = 0x0109
kFlashMediaGetFlashVariableSelect = 0x010A
kFlashMediaSetFlashVariableSelect = 0x010B
kFlashMediaDoButtonActionsSelect = 0x010C
kFlashMediaGetSupportedSwfVersionSelect = 0x010D
kMovieMediaGetChildDoMCActionCallbackSelect = 0x0102
kMovieMediaGetDoMCActionCallbackSelect = 0x0103
kMovieMediaGetCurrentMoviePropertySelect = 0x0104
kMovieMediaGetCurrentTrackPropertySelect = 0x0105
kMovieMediaGetChildMovieDataReferenceSelect = 0x0106
kMovieMediaSetChildMovieDataReferenceSelect = 0x0107
kMovieMediaLoadChildMovieFromDataReferenceSelect = 0x0108
kMedia3DGetNamedObjectListSelect = 0x0101
kMedia3DGetRendererListSelect = 0x0102
kMedia3DGetCurrentGroupSelect = 0x0103
kMedia3DTranslateNamedObjectToSelect = 0x0104
kMedia3DScaleNamedObjectToSelect = 0x0105
kMedia3DRotateNamedObjectToSelect = 0x0106
kMedia3DSetCameraDataSelect = 0x0107
kMedia3DGetCameraDataSelect = 0x0108
kMedia3DSetCameraAngleAspectSelect = 0x0109
kMedia3DGetCameraAngleAspectSelect = 0x010A
kMedia3DSetCameraRangeSelect = 0x010D
kMedia3DGetCameraRangeSelect = 0x010E
kMedia3DGetViewObjectSelect = 0x010F
kMCSetMovieSelect = 0x0002
kMCGetIndMovieSelect = 0x0005
kMCRemoveAllMoviesSelect = 0x0006
kMCRemoveAMovieSelect = 0x0003
kMCRemoveMovieSelect = 0x0006
kMCIsPlayerEventSelect = 0x0007
kMCSetActionFilterSelect = 0x0008
kMCDoActionSelect = 0x0009
kMCSetControllerAttachedSelect = 0x000A
kMCIsControllerAttachedSelect = 0x000B
kMCSetControllerPortSelect = 0x000C
kMCGetControllerPortSelect = 0x000D
kMCSetVisibleSelect = 0x000E
kMCGetVisibleSelect = 0x000F
kMCGetControllerBoundsRectSelect = 0x0010
kMCSetControllerBoundsRectSelect = 0x0011
kMCGetControllerBoundsRgnSelect = 0x0012
kMCGetWindowRgnSelect = 0x0013
kMCMovieChangedSelect = 0x0014
kMCSetDurationSelect = 0x0015
kMCGetCurrentTimeSelect = 0x0016
kMCNewAttachedControllerSelect = 0x0017
kMCDrawSelect = 0x0018
kMCActivateSelect = 0x0019
kMCIdleSelect = 0x001A
kMCKeySelect = 0x001B
kMCClickSelect = 0x001C
kMCEnableEditingSelect = 0x001D
kMCIsEditingEnabledSelect = 0x001E
kMCCopySelect = 0x001F
kMCCutSelect = 0x0020
kMCPasteSelect = 0x0021
kMCClearSelect = 0x0022
kMCUndoSelect = 0x0023
kMCPositionControllerSelect = 0x0024
kMCGetControllerInfoSelect = 0x0025
kMCSetClipSelect = 0x0028
kMCGetClipSelect = 0x0029
kMCDrawBadgeSelect = 0x002A
kMCSetUpEditMenuSelect = 0x002B
kMCGetMenuStringSelect = 0x002C
kMCSetActionFilterWithRefConSelect = 0x002D
kMCPtInControllerSelect = 0x002E
kMCInvalidateSelect = 0x002F
kMCAdjustCursorSelect = 0x0030
kMCGetInterfaceElementSelect = 0x0031
kMCGetDoActionsProcSelect = 0x0032
kMCAddMovieSegmentSelect = 0x0033
kMCTrimMovieSegmentSelect = 0x0034
kMCSetIdleManagerSelect = 0x0035
kMCSetControllerCapabilitiesSelect = 0x0036
kMusicMediaGetIndexedTunePlayerSelect = 0x0101
kRawCodecType = FOUR_CHAR_CODE('raw ')
kCinepakCodecType = FOUR_CHAR_CODE('cvid')
kGraphicsCodecType = FOUR_CHAR_CODE('smc ')
kAnimationCodecType = FOUR_CHAR_CODE('rle ')
kVideoCodecType = FOUR_CHAR_CODE('rpza')
kComponentVideoCodecType = FOUR_CHAR_CODE('yuv2')
kJPEGCodecType = FOUR_CHAR_CODE('jpeg')
kMotionJPEGACodecType = FOUR_CHAR_CODE('mjpa')
kMotionJPEGBCodecType = FOUR_CHAR_CODE('mjpb')
kSGICodecType = FOUR_CHAR_CODE('.SGI')
kPlanarRGBCodecType = FOUR_CHAR_CODE('8BPS')
kMacPaintCodecType = FOUR_CHAR_CODE('PNTG')
kGIFCodecType = FOUR_CHAR_CODE('gif ')
kPhotoCDCodecType = FOUR_CHAR_CODE('kpcd')
kQuickDrawGXCodecType = FOUR_CHAR_CODE('qdgx')
kAVRJPEGCodecType = FOUR_CHAR_CODE('avr ')
kOpenDMLJPEGCodecType = FOUR_CHAR_CODE('dmb1')
kBMPCodecType = FOUR_CHAR_CODE('WRLE')
kWindowsRawCodecType = FOUR_CHAR_CODE('WRAW')
kVectorCodecType = FOUR_CHAR_CODE('path')
kQuickDrawCodecType = FOUR_CHAR_CODE('qdrw')
kWaterRippleCodecType = FOUR_CHAR_CODE('ripl')
kFireCodecType = FOUR_CHAR_CODE('fire')
kCloudCodecType = FOUR_CHAR_CODE('clou')
kH261CodecType = FOUR_CHAR_CODE('h261')
kH263CodecType = FOUR_CHAR_CODE('h263')
kDVCNTSCCodecType = FOUR_CHAR_CODE('dvc ')
kDVCPALCodecType = FOUR_CHAR_CODE('dvcp')
kDVCProPALCodecType = FOUR_CHAR_CODE('dvpp')
kBaseCodecType = FOUR_CHAR_CODE('base')
kFLCCodecType = FOUR_CHAR_CODE('flic')
kTargaCodecType = FOUR_CHAR_CODE('tga ')
kPNGCodecType = FOUR_CHAR_CODE('png ')
kTIFFCodecType = FOUR_CHAR_CODE('tiff')
kComponentVideoSigned = FOUR_CHAR_CODE('yuvu')
kComponentVideoUnsigned = FOUR_CHAR_CODE('yuvs')
kCMYKCodecType = FOUR_CHAR_CODE('cmyk')
kMicrosoftVideo1CodecType = FOUR_CHAR_CODE('msvc')
kSorensonCodecType = FOUR_CHAR_CODE('SVQ1')
kSorenson3CodecType = FOUR_CHAR_CODE('SVQ3')
kIndeo4CodecType = FOUR_CHAR_CODE('IV41')
kMPEG4VisualCodecType = FOUR_CHAR_CODE('mp4v')
k64ARGBCodecType = FOUR_CHAR_CODE('b64a')
k48RGBCodecType = FOUR_CHAR_CODE('b48r')
k32AlphaGrayCodecType = FOUR_CHAR_CODE('b32a')
k16GrayCodecType = FOUR_CHAR_CODE('b16g')
kMpegYUV420CodecType = FOUR_CHAR_CODE('myuv')
kYUV420CodecType = FOUR_CHAR_CODE('y420')
kSorensonYUV9CodecType = FOUR_CHAR_CODE('syv9')
k422YpCbCr8CodecType = FOUR_CHAR_CODE('2vuy')
k444YpCbCr8CodecType = FOUR_CHAR_CODE('v308')
k4444YpCbCrA8CodecType = FOUR_CHAR_CODE('v408')
k422YpCbCr16CodecType = FOUR_CHAR_CODE('v216')
k422YpCbCr10CodecType = FOUR_CHAR_CODE('v210')
k444YpCbCr10CodecType = FOUR_CHAR_CODE('v410')
k4444YpCbCrA8RCodecType = FOUR_CHAR_CODE('r408')
kBlurImageFilterType = FOUR_CHAR_CODE('blur')
kSharpenImageFilterType = FOUR_CHAR_CODE('shrp')
kEdgeDetectImageFilterType = FOUR_CHAR_CODE('edge')
kEmbossImageFilterType = FOUR_CHAR_CODE('embs')
kConvolveImageFilterType = FOUR_CHAR_CODE('genk')
kAlphaGainImageFilterType = FOUR_CHAR_CODE('gain')
kRGBColorBalanceImageFilterType = FOUR_CHAR_CODE('rgbb')
kHSLColorBalanceImageFilterType = FOUR_CHAR_CODE('hslb')
kColorSyncImageFilterType = FOUR_CHAR_CODE('sync')
kFilmNoiseImageFilterType = FOUR_CHAR_CODE('fmns')
kSolarizeImageFilterType = FOUR_CHAR_CODE('solr')
kColorTintImageFilterType = FOUR_CHAR_CODE('tint')
kLensFlareImageFilterType = FOUR_CHAR_CODE('lens')
kBrightnessContrastImageFilterType = FOUR_CHAR_CODE('brco')
kAlphaCompositorTransitionType = FOUR_CHAR_CODE('blnd')
kCrossFadeTransitionType = FOUR_CHAR_CODE('dslv')
kChannelCompositeEffectType = FOUR_CHAR_CODE('chan')
kChromaKeyTransitionType = FOUR_CHAR_CODE('ckey')
kImplodeTransitionType = FOUR_CHAR_CODE('mplo')
kExplodeTransitionType = FOUR_CHAR_CODE('xplo')
kGradientTransitionType = FOUR_CHAR_CODE('matt')
kPushTransitionType = FOUR_CHAR_CODE('push')
kSlideTransitionType = FOUR_CHAR_CODE('slid')
kWipeTransitionType = FOUR_CHAR_CODE('smpt')
kIrisTransitionType = FOUR_CHAR_CODE('smp2')
kRadialTransitionType = FOUR_CHAR_CODE('smp3')
kMatrixTransitionType = FOUR_CHAR_CODE('smp4')
kZoomTransitionType = FOUR_CHAR_CODE('zoom')
kTravellingMatteEffectType = FOUR_CHAR_CODE('trav')
kCMYKPixelFormat = FOUR_CHAR_CODE('cmyk')
k64ARGBPixelFormat = FOUR_CHAR_CODE('b64a')
k48RGBPixelFormat = FOUR_CHAR_CODE('b48r')
k32AlphaGrayPixelFormat = FOUR_CHAR_CODE('b32a')
k16GrayPixelFormat = FOUR_CHAR_CODE('b16g')
k422YpCbCr8PixelFormat = FOUR_CHAR_CODE('2vuy')
k4444YpCbCrA8PixelFormat = FOUR_CHAR_CODE('v408')
k4444YpCbCrA8RPixelFormat = FOUR_CHAR_CODE('r408')
kYUV420PixelFormat = FOUR_CHAR_CODE('y420')
codecInfoDoes1 = (1L << 0)
codecInfoDoes2 = (1L << 1)
codecInfoDoes4 = (1L << 2)
codecInfoDoes8 = (1L << 3)
codecInfoDoes16 = (1L << 4)
codecInfoDoes32 = (1L << 5)
codecInfoDoesDither = (1L << 6)
codecInfoDoesStretch = (1L << 7)
codecInfoDoesShrink = (1L << 8)
codecInfoDoesMask = (1L << 9)
codecInfoDoesTemporal = (1L << 10)
codecInfoDoesDouble = (1L << 11)
codecInfoDoesQuad = (1L << 12)
codecInfoDoesHalf = (1L << 13)
codecInfoDoesQuarter = (1L << 14)
codecInfoDoesRotate = (1L << 15)
codecInfoDoesHorizFlip = (1L << 16)
codecInfoDoesVertFlip = (1L << 17)
codecInfoHasEffectParameterList = (1L << 18)
codecInfoDoesBlend = (1L << 19)
codecInfoDoesWarp = (1L << 20)
codecInfoDoesRecompress = (1L << 21)
codecInfoDoesSpool = (1L << 22)
codecInfoDoesRateConstrain = (1L << 23)
codecInfoDepth1 = (1L << 0)
codecInfoDepth2 = (1L << 1)
codecInfoDepth4 = (1L << 2)
codecInfoDepth8 = (1L << 3)
codecInfoDepth16 = (1L << 4)
codecInfoDepth32 = (1L << 5)
codecInfoDepth24 = (1L << 6)
codecInfoDepth33 = (1L << 7)
codecInfoDepth34 = (1L << 8)
codecInfoDepth36 = (1L << 9)
codecInfoDepth40 = (1L << 10)
codecInfoStoresClut = (1L << 11)
codecInfoDoesLossless = (1L << 12)
codecInfoSequenceSensitive = (1L << 13)
codecFlagUseImageBuffer = (1L << 0)
codecFlagUseScreenBuffer = (1L << 1)
codecFlagUpdatePrevious = (1L << 2)
codecFlagNoScreenUpdate = (1L << 3)
codecFlagWasCompressed = (1L << 4)
codecFlagDontOffscreen = (1L << 5)
codecFlagUpdatePreviousComp = (1L << 6)
codecFlagForceKeyFrame = (1L << 7)
codecFlagOnlyScreenUpdate = (1L << 8)
codecFlagLiveGrab = (1L << 9)
codecFlagDiffFrame = (1L << 9)
codecFlagDontUseNewImageBuffer = (1L << 10)
codecFlagInterlaceUpdate = (1L << 11)
codecFlagCatchUpDiff = (1L << 12)
codecFlagSupportDisable = (1L << 13)
codecFlagReenable = (1L << 14)
codecFlagOutUpdateOnNextIdle = (1L << 9)
codecFlagOutUpdateOnDataSourceChange = (1L << 10)
codecFlagSequenceSensitive = (1L << 11)
codecFlagOutUpdateOnTimeChange = (1L << 12)
codecFlagImageBufferNotSourceImage = (1L << 13)
codecFlagUsedNewImageBuffer = (1L << 14)
codecFlagUsedImageBuffer = (1L << 15)
codecMinimumDataSize = 32768L
compressorComponentType = FOUR_CHAR_CODE('imco')
decompressorComponentType = FOUR_CHAR_CODE('imdc')
codecLosslessQuality = 0x00000400
codecMaxQuality = 0x000003FF
codecMinQuality = 0x00000000
codecLowQuality = 0x00000100
codecNormalQuality = 0x00000200
codecHighQuality = 0x00000300
codecLockBitsShieldCursor = (1 << 0)
codecCompletionSource = (1 << 0)
codecCompletionDest = (1 << 1)
codecCompletionDontUnshield = (1 << 2)
codecCompletionWentOffscreen = (1 << 3)
codecCompletionUnlockBits = (1 << 4)
codecCompletionForceChainFlush = (1 << 5)
codecCompletionDropped = (1 << 6)
codecProgressOpen = 0
codecProgressUpdatePercent = 1
codecProgressClose = 2
defaultDither = 0
forceDither = 1
suppressDither = 2
useColorMatching = 4
callStdBits = 1
callOldBits = 2
noDefaultOpcodes = 4
graphicsModeStraightAlpha = 256
graphicsModePreWhiteAlpha = 257
graphicsModePreBlackAlpha = 258
graphicsModeComposition = 259
graphicsModeStraightAlphaBlend = 260
graphicsModePreMulColorAlpha = 261
evenField1ToEvenFieldOut = 1 << 0
evenField1ToOddFieldOut = 1 << 1
oddField1ToEvenFieldOut = 1 << 2
oddField1ToOddFieldOut = 1 << 3
evenField2ToEvenFieldOut = 1 << 4
evenField2ToOddFieldOut = 1 << 5
oddField2ToEvenFieldOut = 1 << 6
oddField2ToOddFieldOut = 1 << 7
icmFrameTimeHasVirtualStartTimeAndDuration = 1 << 0
codecDSequenceDisableOverlaySurface = (1L << 5)
codecDSequenceSingleField = (1L << 6)
codecDSequenceBidirectionalPrediction = (1L << 7)
codecDSequenceFlushInsteadOfDirtying = (1L << 8)
codecDSequenceEnableSubPixelPositioning = (1L << 9)
kICMSequenceTaskWeight = FOUR_CHAR_CODE('twei')
kICMSequenceTaskName = FOUR_CHAR_CODE('tnam')
kICMSequenceUserPreferredCodecs = FOUR_CHAR_CODE('punt')
kImageDescriptionSampleFormat = FOUR_CHAR_CODE('idfm')
kImageDescriptionClassicAtomFormat = FOUR_CHAR_CODE('atom')
kImageDescriptionQTAtomFormat = FOUR_CHAR_CODE('qtat')
kImageDescriptionEffectDataFormat = FOUR_CHAR_CODE('fxat')
kImageDescriptionPrivateDataFormat = FOUR_CHAR_CODE('priv')
kImageDescriptionAlternateCodec = FOUR_CHAR_CODE('subs')
kImageDescriptionColorSpace = FOUR_CHAR_CODE('cspc')
sfpItemPreviewAreaUser = 11
sfpItemPreviewStaticText = 12
sfpItemPreviewDividerUser = 13
sfpItemCreatePreviewButton = 14
sfpItemShowPreviewButton = 15
kICMPixelFormatIsPlanarMask = 0x0F
kICMPixelFormatIsIndexed = (1L << 4)
kICMPixelFormatIsSupportedByQD = (1L << 5)
kICMPixelFormatIsMonochrome = (1L << 6)
kICMPixelFormatHasAlphaChannel = (1L << 7)
kICMGetChainUltimateParent = 0
kICMGetChainParent = 1
kICMGetChainChild = 2
kICMGetChainUltimateChild = 3
kDontUseValidateToFindGraphicsImporter = 1L << 0
kICMTempThenAppMemory = 1L << 12
kICMAppThenTempMemory = 1L << 13
kQTUsePlatformDefaultGammaLevel = 0
kQTUseSourceGammaLevel = -1L
kQTCCIR601VideoGammaLevel = 0x00023333
identityMatrixType = 0x00
translateMatrixType = 0x01
scaleMatrixType = 0x02
scaleTranslateMatrixType = 0x03
linearMatrixType = 0x04
linearTranslateMatrixType = 0x05
perspectiveMatrixType = 0x06
GraphicsImporterComponentType = FOUR_CHAR_CODE('grip')
graphicsImporterUsesImageDecompressor = 1L << 23
quickTimeImageFileImageDescriptionAtom = FOUR_CHAR_CODE('idsc')
quickTimeImageFileImageDataAtom = FOUR_CHAR_CODE('idat')
quickTimeImageFileMetaDataAtom = FOUR_CHAR_CODE('meta')
quickTimeImageFileColorSyncProfileAtom = FOUR_CHAR_CODE('iicc')
graphicsImporterDrawsAllPixels = 0
graphicsImporterDoesntDrawAllPixels = 1
graphicsImporterDontKnowIfDrawAllPixels = 2
kGraphicsImporterDontDoGammaCorrection = 1L << 0
kGraphicsImporterTrustResolutionFromFile = 1L << 1
kGraphicsImporterEnableSubPixelPositioning = 1L << 2
kGraphicsExportGroup = FOUR_CHAR_CODE('expo')
kGraphicsExportFileType = FOUR_CHAR_CODE('ftyp')
kGraphicsExportMIMEType = FOUR_CHAR_CODE('mime')
kGraphicsExportExtension = FOUR_CHAR_CODE('ext ')
kGraphicsExportDescription = FOUR_CHAR_CODE('desc')
kQTPhotoshopLayerMode = FOUR_CHAR_CODE('lmod')
kQTPhotoshopLayerOpacity = FOUR_CHAR_CODE('lopa')
kQTPhotoshopLayerClipping = FOUR_CHAR_CODE('lclp')
kQTPhotoshopLayerFlags = FOUR_CHAR_CODE('lflg')
kQTPhotoshopLayerName = FOUR_CHAR_CODE('\xa9lnm')
kQTPhotoshopLayerUnicodeName = FOUR_CHAR_CODE('luni')
kQTIndexedImageType = FOUR_CHAR_CODE('nth?')
kQTIndexedImageIsThumbnail = FOUR_CHAR_CODE('n=th')
kQTIndexedImageIsLayer = FOUR_CHAR_CODE('n=ly')
kQTIndexedImageIsPage = FOUR_CHAR_CODE('n=pg')
kQTIndexedImageIsMultiResolution = FOUR_CHAR_CODE('n=rs')
kQTTIFFUserDataPrefix = 0x74690000
kQTTIFFExifUserDataPrefix = 0x65780000
kQTTIFFExifGPSUserDataPrefix = 0x67700000
kQTAlphaMode = FOUR_CHAR_CODE('almo')
kQTAlphaModePreMulColor = FOUR_CHAR_CODE('almp')
kUserDataIPTC = FOUR_CHAR_CODE('iptc')
kQTTIFFUserDataOrientation = 0x74690112
kQTTIFFUserDataTransferFunction = 0x7469012D
kQTTIFFUserDataWhitePoint = 0x7469013E
kQTTIFFUserDataPrimaryChromaticities = 0x7469013F
kQTTIFFUserDataTransferRange = 0x74690156
kQTTIFFUserDataYCbCrPositioning = 0x74690213
kQTTIFFUserDataReferenceBlackWhite = 0x74690214
kQTTIFFUserDataModelPixelScale = 0x7469830E
kQTTIFFUserDataModelTransformation = 0x746985D8
kQTTIFFUserDataModelTiepoint = 0x74698482
kQTTIFFUserDataGeoKeyDirectory = 0x746987AF
kQTTIFFUserDataGeoDoubleParams = 0x746987B0
kQTTIFFUserDataGeoAsciiParams = 0x746987B1
kQTTIFFUserDataIntergraphMatrix = 0x74698480
kQTExifUserDataExifVersion = 0x65789000
kQTExifUserDataFlashPixVersion = 0x6578A000
kQTExifUserDataColorSpace = 0x6578A001
kQTExifUserDataComponentsConfiguration = 0x65789101
kQTExifUserDataCompressedBitsPerPixel = 0x65789102
kQTExifUserDataPixelXDimension = 0x6578A002
kQTExifUserDataPixelYDimension = 0x6578A003
kQTExifUserDataMakerNote = 0x6578927C
kQTExifUserDataUserComment = 0x6578928C
kQTExifUserDataRelatedSoundFile = 0x6578A004
kQTExifUserDataDateTimeOriginal = 0x65789003
kQTExifUserDataDateTimeDigitized = 0x65789004
kQTExifUserDataSubSecTime = 0x65789290
kQTExifUserDataSubSecTimeOriginal = 0x65789291
kQTExifUserDataSubSecTimeDigitized = 0x65789292
kQTExifUserDataExposureTime = 0x6578829A
kQTExifUserDataFNumber = 0x6578829D
kQTExifUserDataExposureProgram = 0x65788822
kQTExifUserDataSpectralSensitivity = 0x65788824
kQTExifUserDataISOSpeedRatings = 0x65788827
kQTExifUserDataShutterSpeedValue = 0x65789201
kQTExifUserDataApertureValue = 0x65789202
kQTExifUserDataBrightnessValue = 0x65789203
kQTExifUserDataExposureBiasValue = 0x65789204
kQTExifUserDataMaxApertureValue = 0x65789205
kQTExifUserDataSubjectDistance = 0x65789206
kQTExifUserDataMeteringMode = 0x65789207
kQTExifUserDataLightSource = 0x65789208
kQTExifUserDataFlash = 0x65789209
kQTExifUserDataFocalLength = 0x6578920A
kQTExifUserDataFlashEnergy = 0x6578A20B
kQTExifUserDataFocalPlaneXResolution = 0x6578A20E
kQTExifUserDataFocalPlaneYResolution = 0x6578A20F
kQTExifUserDataFocalPlaneResolutionUnit = 0x6578A210
kQTExifUserDataSubjectLocation = 0x6578A214
kQTExifUserDataExposureIndex = 0x6578A215
kQTExifUserDataSensingMethod = 0x6578A217
kQTExifUserDataFileSource = 0x6578A300
kQTExifUserDataSceneType = 0x6578A301
kQTExifUserDataGPSVersionID = 0x06770000
kQTExifUserDataGPSLatitudeRef = 0x06770001
kQTExifUserDataGPSLatitude = 0x06770002
kQTExifUserDataGPSLongitudeRef = 0x06770003
kQTExifUserDataGPSLongitude = 0x06770004
kQTExifUserDataGPSAltitudeRef = 0x06770005
kQTExifUserDataGPSAltitude = 0x06770006
kQTExifUserDataGPSTimeStamp = 0x06770007
kQTExifUserDataGPSSatellites = 0x06770008
kQTExifUserDataGPSStatus = 0x06770009
kQTExifUserDataGPSMeasureMode = 0x0677000A
kQTExifUserDataGPSDOP = 0x0677000B
kQTExifUserDataGPSSpeedRef = 0x0677000C
kQTExifUserDataGPSSpeed = 0x0677000D
kQTExifUserDataGPSTrackRef = 0x0677000E
kQTExifUserDataGPSTrack = 0x0677000F
kQTExifUserDataGPSImgDirectionRef = 0x06770010
kQTExifUserDataGPSImgDirection = 0x06770011
kQTExifUserDataGPSMapDatum = 0x06770012
kQTExifUserDataGPSDestLatitudeRef = 0x06770013
kQTExifUserDataGPSDestLatitude = 0x06770014
kQTExifUserDataGPSDestLongitudeRef = 0x06770015
kQTExifUserDataGPSDestLongitude = 0x06770016
kQTExifUserDataGPSDestBearingRef = 0x06770017
kQTExifUserDataGPSDestBearing = 0x06770018
kQTExifUserDataGPSDestDistanceRef = 0x06770019
kQTExifUserDataGPSDestDistance = 0x0677001A
GraphicsExporterComponentType = FOUR_CHAR_CODE('grex')
kBaseGraphicsExporterSubType = FOUR_CHAR_CODE('base')
graphicsExporterIsBaseExporter = 1L << 0
graphicsExporterCanTranscode = 1L << 1
graphicsExporterUsesImageCompressor = 1L << 2
kQTResolutionSettings = FOUR_CHAR_CODE('reso')
kQTTargetDataSize = FOUR_CHAR_CODE('dasz')
kQTDontRecompress = FOUR_CHAR_CODE('dntr')
kQTInterlaceStyle = FOUR_CHAR_CODE('ilac')
kQTColorSyncProfile = FOUR_CHAR_CODE('iccp')
kQTThumbnailSettings = FOUR_CHAR_CODE('thum')
kQTEnableExif = FOUR_CHAR_CODE('exif')
kQTMetaData = FOUR_CHAR_CODE('meta')
kQTTIFFCompressionMethod = FOUR_CHAR_CODE('tifc')
kQTTIFFCompression_None = 1
kQTTIFFCompression_PackBits = 32773L
kQTTIFFLittleEndian = FOUR_CHAR_CODE('tife')
kQTPNGFilterPreference = FOUR_CHAR_CODE('pngf')
kQTPNGFilterBestForColorType = FOUR_CHAR_CODE('bflt')
kQTPNGFilterNone = 0
kQTPNGFilterSub = 1
kQTPNGFilterUp = 2
kQTPNGFilterAverage = 3
kQTPNGFilterPaeth = 4
kQTPNGFilterAdaptivePerRow = FOUR_CHAR_CODE('aflt')
kQTPNGInterlaceStyle = FOUR_CHAR_CODE('ilac')
kQTPNGInterlaceNone = 0
kQTPNGInterlaceAdam7 = 1
ImageTranscodererComponentType = FOUR_CHAR_CODE('imtc')
kGraphicsImportSetDataReferenceSelect = 0x0001
kGraphicsImportGetDataReferenceSelect = 0x0002
kGraphicsImportSetDataFileSelect = 0x0003
kGraphicsImportGetDataFileSelect = 0x0004
kGraphicsImportSetDataHandleSelect = 0x0005
kGraphicsImportGetDataHandleSelect = 0x0006
kGraphicsImportGetImageDescriptionSelect = 0x0007
kGraphicsImportGetDataOffsetAndSizeSelect = 0x0008
kGraphicsImportReadDataSelect = 0x0009
kGraphicsImportSetClipSelect = 0x000A
kGraphicsImportGetClipSelect = 0x000B
kGraphicsImportSetSourceRectSelect = 0x000C
kGraphicsImportGetSourceRectSelect = 0x000D
kGraphicsImportGetNaturalBoundsSelect = 0x000E
kGraphicsImportDrawSelect = 0x000F
kGraphicsImportSetGWorldSelect = 0x0010
kGraphicsImportGetGWorldSelect = 0x0011
kGraphicsImportSetMatrixSelect = 0x0012
kGraphicsImportGetMatrixSelect = 0x0013
kGraphicsImportSetBoundsRectSelect = 0x0014
kGraphicsImportGetBoundsRectSelect = 0x0015
kGraphicsImportSaveAsPictureSelect = 0x0016
kGraphicsImportSetGraphicsModeSelect = 0x0017
kGraphicsImportGetGraphicsModeSelect = 0x0018
kGraphicsImportSetQualitySelect = 0x0019
kGraphicsImportGetQualitySelect = 0x001A
kGraphicsImportSaveAsQuickTimeImageFileSelect = 0x001B
kGraphicsImportSetDataReferenceOffsetAndLimitSelect = 0x001C
kGraphicsImportGetDataReferenceOffsetAndLimitSelect = 0x001D
kGraphicsImportGetAliasedDataReferenceSelect = 0x001E
kGraphicsImportValidateSelect = 0x001F
kGraphicsImportGetMetaDataSelect = 0x0020
kGraphicsImportGetMIMETypeListSelect = 0x0021
kGraphicsImportDoesDrawAllPixelsSelect = 0x0022
kGraphicsImportGetAsPictureSelect = 0x0023
kGraphicsImportExportImageFileSelect = 0x0024
kGraphicsImportGetExportImageTypeListSelect = 0x0025
kGraphicsImportDoExportImageFileDialogSelect = 0x0026
kGraphicsImportGetExportSettingsAsAtomContainerSelect = 0x0027
kGraphicsImportSetExportSettingsFromAtomContainerSelect = 0x0028
kGraphicsImportSetProgressProcSelect = 0x0029
kGraphicsImportGetProgressProcSelect = 0x002A
kGraphicsImportGetImageCountSelect = 0x002B
kGraphicsImportSetImageIndexSelect = 0x002C
kGraphicsImportGetImageIndexSelect = 0x002D
kGraphicsImportGetDataOffsetAndSize64Select = 0x002E
kGraphicsImportReadData64Select = 0x002F
kGraphicsImportSetDataReferenceOffsetAndLimit64Select = 0x0030
kGraphicsImportGetDataReferenceOffsetAndLimit64Select = 0x0031
kGraphicsImportGetDefaultMatrixSelect = 0x0032
kGraphicsImportGetDefaultClipSelect = 0x0033
kGraphicsImportGetDefaultGraphicsModeSelect = 0x0034
kGraphicsImportGetDefaultSourceRectSelect = 0x0035
kGraphicsImportGetColorSyncProfileSelect = 0x0036
kGraphicsImportSetDestRectSelect = 0x0037
kGraphicsImportGetDestRectSelect = 0x0038
kGraphicsImportSetFlagsSelect = 0x0039
kGraphicsImportGetFlagsSelect = 0x003A
kGraphicsImportGetBaseDataOffsetAndSize64Select = 0x003D
kGraphicsImportSetImageIndexToThumbnailSelect = 0x003E
kGraphicsExportDoExportSelect = 0x0001
kGraphicsExportCanTranscodeSelect = 0x0002
kGraphicsExportDoTranscodeSelect = 0x0003
kGraphicsExportCanUseCompressorSelect = 0x0004
kGraphicsExportDoUseCompressorSelect = 0x0005
kGraphicsExportDoStandaloneExportSelect = 0x0006
kGraphicsExportGetDefaultFileTypeAndCreatorSelect = 0x0007
kGraphicsExportGetDefaultFileNameExtensionSelect = 0x0008
kGraphicsExportGetMIMETypeListSelect = 0x0009
kGraphicsExportRequestSettingsSelect = 0x000B
kGraphicsExportSetSettingsFromAtomContainerSelect = 0x000C
kGraphicsExportGetSettingsAsAtomContainerSelect = 0x000D
kGraphicsExportGetSettingsAsTextSelect = 0x000E
kGraphicsExportSetDontRecompressSelect = 0x000F
kGraphicsExportGetDontRecompressSelect = 0x0010
kGraphicsExportSetInterlaceStyleSelect = 0x0011
kGraphicsExportGetInterlaceStyleSelect = 0x0012
kGraphicsExportSetMetaDataSelect = 0x0013
kGraphicsExportGetMetaDataSelect = 0x0014
kGraphicsExportSetTargetDataSizeSelect = 0x0015
kGraphicsExportGetTargetDataSizeSelect = 0x0016
kGraphicsExportSetCompressionMethodSelect = 0x0017
kGraphicsExportGetCompressionMethodSelect = 0x0018
kGraphicsExportSetCompressionQualitySelect = 0x0019
kGraphicsExportGetCompressionQualitySelect = 0x001A
kGraphicsExportSetResolutionSelect = 0x001B
kGraphicsExportGetResolutionSelect = 0x001C
kGraphicsExportSetDepthSelect = 0x001D
kGraphicsExportGetDepthSelect = 0x001E
kGraphicsExportSetColorSyncProfileSelect = 0x0021
kGraphicsExportGetColorSyncProfileSelect = 0x0022
kGraphicsExportSetProgressProcSelect = 0x0023
kGraphicsExportGetProgressProcSelect = 0x0024
kGraphicsExportSetInputDataReferenceSelect = 0x0025
kGraphicsExportGetInputDataReferenceSelect = 0x0026
kGraphicsExportSetInputFileSelect = 0x0027
kGraphicsExportGetInputFileSelect = 0x0028
kGraphicsExportSetInputHandleSelect = 0x0029
kGraphicsExportGetInputHandleSelect = 0x002A
kGraphicsExportSetInputPtrSelect = 0x002B
kGraphicsExportGetInputPtrSelect = 0x002C
kGraphicsExportSetInputGraphicsImporterSelect = 0x002D
kGraphicsExportGetInputGraphicsImporterSelect = 0x002E
kGraphicsExportSetInputPictureSelect = 0x002F
kGraphicsExportGetInputPictureSelect = 0x0030
kGraphicsExportSetInputGWorldSelect = 0x0031
kGraphicsExportGetInputGWorldSelect = 0x0032
kGraphicsExportSetInputPixmapSelect = 0x0033
kGraphicsExportGetInputPixmapSelect = 0x0034
kGraphicsExportSetInputOffsetAndLimitSelect = 0x0035
kGraphicsExportGetInputOffsetAndLimitSelect = 0x0036
kGraphicsExportMayExporterReadInputDataSelect = 0x0037
kGraphicsExportGetInputDataSizeSelect = 0x0038
kGraphicsExportReadInputDataSelect = 0x0039
kGraphicsExportGetInputImageDescriptionSelect = 0x003A
kGraphicsExportGetInputImageDimensionsSelect = 0x003B
kGraphicsExportGetInputImageDepthSelect = 0x003C
kGraphicsExportDrawInputImageSelect = 0x003D
kGraphicsExportSetOutputDataReferenceSelect = 0x003E
kGraphicsExportGetOutputDataReferenceSelect = 0x003F
kGraphicsExportSetOutputFileSelect = 0x0040
kGraphicsExportGetOutputFileSelect = 0x0041
kGraphicsExportSetOutputHandleSelect = 0x0042
kGraphicsExportGetOutputHandleSelect = 0x0043
kGraphicsExportSetOutputOffsetAndMaxSizeSelect = 0x0044
kGraphicsExportGetOutputOffsetAndMaxSizeSelect = 0x0045
kGraphicsExportSetOutputFileTypeAndCreatorSelect = 0x0046
kGraphicsExportGetOutputFileTypeAndCreatorSelect = 0x0047
kGraphicsExportWriteOutputDataSelect = 0x0048
kGraphicsExportSetOutputMarkSelect = 0x0049
kGraphicsExportGetOutputMarkSelect = 0x004A
kGraphicsExportReadOutputDataSelect = 0x004B
kGraphicsExportSetThumbnailEnabledSelect = 0x004C
kGraphicsExportGetThumbnailEnabledSelect = 0x004D
kGraphicsExportSetExifEnabledSelect = 0x004E
kGraphicsExportGetExifEnabledSelect = 0x004F
kImageTranscoderBeginSequenceSelect = 0x0001
kImageTranscoderConvertSelect = 0x0002
kImageTranscoderDisposeDataSelect = 0x0003
kImageTranscoderEndSequenceSelect = 0x0004
clockComponentType = FOUR_CHAR_CODE('clok')
systemTickClock = FOUR_CHAR_CODE('tick')
systemSecondClock = FOUR_CHAR_CODE('seco')
systemMillisecondClock = FOUR_CHAR_CODE('mill')
systemMicrosecondClock = FOUR_CHAR_CODE('micr')
kClockRateIsLinear = 1
kClockImplementsCallBacks = 2
kClockCanHandleIntermittentSound = 4
StandardCompressionType = FOUR_CHAR_CODE('scdi')
StandardCompressionSubType = FOUR_CHAR_CODE('imag')
StandardCompressionSubTypeSound = FOUR_CHAR_CODE('soun')
scListEveryCodec = 1L << 1
scAllowZeroFrameRate = 1L << 2
scAllowZeroKeyFrameRate = 1L << 3
scShowBestDepth = 1L << 4
scUseMovableModal = 1L << 5
scDisableFrameRateItem = 1L << 6
scShowDataRateAsKilobits = 1L << 7
scPreferCropping = 1 << 0
scPreferScaling = 1 << 1
scPreferScalingAndCropping = scPreferScaling | scPreferCropping
scDontDetermineSettingsFromTestImage = 1 << 2
scTestImageWidth = 80
scTestImageHeight = 80
scOKItem = 1
scCancelItem = 2
scCustomItem = 3
scUserCancelled = 1
scPositionRect = 2
scPositionDialog = 3
scSetTestImagePictHandle = 4
scSetTestImagePictFile = 5
scSetTestImagePixMap = 6
scGetBestDeviceRect = 7
scRequestImageSettings = 10
scCompressImage = 11
scCompressPicture = 12
scCompressPictureFile = 13
scRequestSequenceSettings = 14
scCompressSequenceBegin = 15
scCompressSequenceFrame = 16
scCompressSequenceEnd = 17
scDefaultPictHandleSettings = 18
scDefaultPictFileSettings = 19
scDefaultPixMapSettings = 20
scGetInfo = 21
scSetInfo = 22
scNewGWorld = 23
scSpatialSettingsType = FOUR_CHAR_CODE('sptl')
scTemporalSettingsType = FOUR_CHAR_CODE('tprl')
scDataRateSettingsType = FOUR_CHAR_CODE('drat')
scColorTableType = FOUR_CHAR_CODE('clut')
scProgressProcType = FOUR_CHAR_CODE('prog')
scExtendedProcsType = FOUR_CHAR_CODE('xprc')
scPreferenceFlagsType = FOUR_CHAR_CODE('pref')
scSettingsStateType = FOUR_CHAR_CODE('ssta')
scSequenceIDType = FOUR_CHAR_CODE('sequ')
scWindowPositionType = FOUR_CHAR_CODE('wndw')
scCodecFlagsType = FOUR_CHAR_CODE('cflg')
scCodecSettingsType = FOUR_CHAR_CODE('cdec')
scForceKeyValueType = FOUR_CHAR_CODE('ksim')
scSoundSampleRateType = FOUR_CHAR_CODE('ssrt')
scSoundSampleSizeType = FOUR_CHAR_CODE('ssss')
scSoundChannelCountType = FOUR_CHAR_CODE('sscc')
scSoundCompressionType = FOUR_CHAR_CODE('ssct')
scCompressionListType = FOUR_CHAR_CODE('ctyl')
scCodecManufacturerType = FOUR_CHAR_CODE('cmfr')
scSoundVBRCompressionOK = FOUR_CHAR_CODE('cvbr')
scSoundInputSampleRateType = FOUR_CHAR_CODE('ssir')
scSoundSampleRateChangeOK = FOUR_CHAR_CODE('rcok')
scAvailableCompressionListType = FOUR_CHAR_CODE('avai')
scGetCompression = 1
scShowMotionSettings = 1L << 0
scSettingsChangedItem = -1
scCompressFlagIgnoreIdenticalFrames = 1
kQTSettingsVideo = FOUR_CHAR_CODE('vide')
kQTSettingsSound = FOUR_CHAR_CODE('soun')
kQTSettingsComponentVersion = FOUR_CHAR_CODE('vers')
TweenComponentType = FOUR_CHAR_CODE('twen')
TCSourceRefNameType = FOUR_CHAR_CODE('name')
tcDropFrame = 1 << 0
tc24HourMax = 1 << 1
tcNegTimesOK = 1 << 2
tcCounter = 1 << 3
tctNegFlag = 0x80
tcdfShowTimeCode = 1 << 0
MovieImportType = FOUR_CHAR_CODE('eat ')
MovieExportType = FOUR_CHAR_CODE('spit')
canMovieImportHandles = 1 << 0
canMovieImportFiles = 1 << 1
hasMovieImportUserInterface = 1 << 2
canMovieExportHandles = 1 << 3
canMovieExportFiles = 1 << 4
hasMovieExportUserInterface = 1 << 5
movieImporterIsXMLBased = 1 << 5
dontAutoFileMovieImport = 1 << 6
canMovieExportAuxDataHandle = 1 << 7
canMovieImportValidateHandles = 1 << 8
canMovieImportValidateFile = 1 << 9
dontRegisterWithEasyOpen = 1 << 10
canMovieImportInPlace = 1 << 11
movieImportSubTypeIsFileExtension = 1 << 12
canMovieImportPartial = 1 << 13
hasMovieImportMIMEList = 1 << 14
canMovieImportAvoidBlocking = 1 << 15
canMovieExportFromProcedures = 1 << 15
canMovieExportValidateMovie = 1L << 16
movieImportMustGetDestinationMediaType = 1L << 16
movieExportNeedsResourceFork = 1L << 17
canMovieImportDataReferences = 1L << 18
movieExportMustGetSourceMediaType = 1L << 19
canMovieImportWithIdle = 1L << 20
canMovieImportValidateDataReferences = 1L << 21
reservedForUseByGraphicsImporters = 1L << 23
movieImportCreateTrack = 1
movieImportInParallel = 2
movieImportMustUseTrack = 4
movieImportWithIdle = 16
movieImportResultUsedMultipleTracks = 8
movieImportResultNeedIdles = 32
movieImportResultComplete = 64
kMovieExportTextOnly = 0
kMovieExportAbsoluteTime = 1
kMovieExportRelativeTime = 2
kMIDIImportSilenceBefore = 1 << 0
kMIDIImportSilenceAfter = 1 << 1
kMIDIImport20Playable = 1 << 2
kMIDIImportWantLyrics = 1 << 3
kQTMediaConfigResourceType = FOUR_CHAR_CODE('mcfg')
kQTMediaConfigResourceVersion = 2
kQTMediaGroupResourceType = FOUR_CHAR_CODE('mgrp')
kQTMediaGroupResourceVersion = 1
kQTBrowserInfoResourceType = FOUR_CHAR_CODE('brws')
kQTBrowserInfoResourceVersion = 1
kQTMediaMIMEInfoHasChanged = (1L << 1)
kQTMediaFileInfoHasChanged = (1L << 2)
kQTMediaConfigCanUseApp = (1L << 18)
kQTMediaConfigCanUsePlugin = (1L << 19)
kQTMediaConfigUNUSED = (1L << 20)
kQTMediaConfigBinaryFile = (1L << 23)
kQTMediaConfigTextFile = 0
kQTMediaConfigMacintoshFile = (1L << 24)
kQTMediaConfigAssociateByDefault = (1L << 27)
kQTMediaConfigUseAppByDefault = (1L << 28)
kQTMediaConfigUsePluginByDefault = (1L << 29)
kQTMediaConfigDefaultsMask = (kQTMediaConfigUseAppByDefault | kQTMediaConfigUsePluginByDefault)
kQTMediaConfigDefaultsShift = 12
kQTMediaConfigHasFileHasQTAtoms = (1L << 30)
kQTMediaConfigStreamGroupID = FOUR_CHAR_CODE('strm')
kQTMediaConfigInteractiveGroupID = FOUR_CHAR_CODE('intr')
kQTMediaConfigVideoGroupID = FOUR_CHAR_CODE('eyes')
kQTMediaConfigAudioGroupID = FOUR_CHAR_CODE('ears')
kQTMediaConfigMPEGGroupID = FOUR_CHAR_CODE('mpeg')
kQTMediaConfigMP3GroupID = FOUR_CHAR_CODE('mp3 ')
kQTMediaConfigImageGroupID = FOUR_CHAR_CODE('ogle')
kQTMediaConfigMiscGroupID = FOUR_CHAR_CODE('misc')
kQTMediaInfoNetGroup = FOUR_CHAR_CODE('net ')
kQTMediaInfoWinGroup = FOUR_CHAR_CODE('win ')
kQTMediaInfoMacGroup = FOUR_CHAR_CODE('mac ')
kQTMediaInfoMiscGroup = 0x3F3F3F3F
kMimeInfoMimeTypeTag = FOUR_CHAR_CODE('mime')
kMimeInfoFileExtensionTag = FOUR_CHAR_CODE('ext ')
kMimeInfoDescriptionTag = FOUR_CHAR_CODE('desc')
kMimeInfoGroupTag = FOUR_CHAR_CODE('grop')
kMimeInfoDoNotOverrideExistingFileTypeAssociation = FOUR_CHAR_CODE('nofa')
kQTFileTypeAIFF = FOUR_CHAR_CODE('AIFF')
kQTFileTypeAIFC = FOUR_CHAR_CODE('AIFC')
kQTFileTypeDVC = FOUR_CHAR_CODE('dvc!')
kQTFileTypeMIDI = FOUR_CHAR_CODE('Midi')
kQTFileTypePicture = FOUR_CHAR_CODE('PICT')
kQTFileTypeMovie = FOUR_CHAR_CODE('MooV')
kQTFileTypeText = FOUR_CHAR_CODE('TEXT')
kQTFileTypeWave = FOUR_CHAR_CODE('WAVE')
kQTFileTypeSystemSevenSound = FOUR_CHAR_CODE('sfil')
kQTFileTypeMuLaw = FOUR_CHAR_CODE('ULAW')
kQTFileTypeAVI = FOUR_CHAR_CODE('VfW ')
kQTFileTypeSoundDesignerII = FOUR_CHAR_CODE('Sd2f')
kQTFileTypeAudioCDTrack = FOUR_CHAR_CODE('trak')
kQTFileTypePICS = FOUR_CHAR_CODE('PICS')
kQTFileTypeGIF = FOUR_CHAR_CODE('GIFf')
kQTFileTypePNG = FOUR_CHAR_CODE('PNGf')
kQTFileTypeTIFF = FOUR_CHAR_CODE('TIFF')
kQTFileTypePhotoShop = FOUR_CHAR_CODE('8BPS')
kQTFileTypeSGIImage = FOUR_CHAR_CODE('.SGI')
kQTFileTypeBMP = FOUR_CHAR_CODE('BMPf')
kQTFileTypeJPEG = FOUR_CHAR_CODE('JPEG')
kQTFileTypeJFIF = FOUR_CHAR_CODE('JPEG')
kQTFileTypeMacPaint = FOUR_CHAR_CODE('PNTG')
kQTFileTypeTargaImage = FOUR_CHAR_CODE('TPIC')
kQTFileTypeQuickDrawGXPicture = FOUR_CHAR_CODE('qdgx')
kQTFileTypeQuickTimeImage = FOUR_CHAR_CODE('qtif')
kQTFileType3DMF = FOUR_CHAR_CODE('3DMF')
kQTFileTypeFLC = FOUR_CHAR_CODE('FLC ')
kQTFileTypeFlash = FOUR_CHAR_CODE('SWFL')
kQTFileTypeFlashPix = FOUR_CHAR_CODE('FPix')
kQTFileTypeMP4 = FOUR_CHAR_CODE('mpg4')
kQTSettingsDVExportNTSC = FOUR_CHAR_CODE('dvcv')
kQTSettingsDVExportLockedAudio = FOUR_CHAR_CODE('lock')
kQTSettingsEffect = FOUR_CHAR_CODE('effe')
kQTSettingsGraphicsFileImportSequence = FOUR_CHAR_CODE('sequ')
kQTSettingsGraphicsFileImportSequenceEnabled = FOUR_CHAR_CODE('enab')
kQTSettingsMovieExportEnableVideo = FOUR_CHAR_CODE('envi')
kQTSettingsMovieExportEnableSound = FOUR_CHAR_CODE('enso')
kQTSettingsMovieExportSaveOptions = FOUR_CHAR_CODE('save')
kQTSettingsMovieExportSaveForInternet = FOUR_CHAR_CODE('fast')
kQTSettingsMovieExportSaveCompressedMovie = FOUR_CHAR_CODE('cmpm')
kQTSettingsMIDI = FOUR_CHAR_CODE('MIDI')
kQTSettingsMIDISettingFlags = FOUR_CHAR_CODE('sttg')
kQTSettingsText = FOUR_CHAR_CODE('text')
kQTSettingsTextDescription = FOUR_CHAR_CODE('desc')
kQTSettingsTextSize = FOUR_CHAR_CODE('size')
kQTSettingsTextSettingFlags = FOUR_CHAR_CODE('sttg')
kQTSettingsTextTimeFraction = FOUR_CHAR_CODE('timf')
kQTSettingsTime = FOUR_CHAR_CODE('time')
kQTSettingsTimeDuration = FOUR_CHAR_CODE('dura')
kQTSettingsAudioCDTrack = FOUR_CHAR_CODE('trak')
kQTSettingsAudioCDTrackRateShift = FOUR_CHAR_CODE('rshf')
kQTSettingsDVExportDVFormat = FOUR_CHAR_CODE('dvcf')
kQTPresetsListResourceType = FOUR_CHAR_CODE('stg#')
kQTPresetsPlatformListResourceType = FOUR_CHAR_CODE('stgp')
kQTPresetInfoIsDivider = 1
kQTMovieExportSourceInfoResourceType = FOUR_CHAR_CODE('src#')
kQTMovieExportSourceInfoIsMediaType = 1L << 0
kQTMovieExportSourceInfoIsMediaCharacteristic = 1L << 1
kQTMovieExportSourceInfoIsSourceType = 1L << 2
movieExportUseConfiguredSettings = FOUR_CHAR_CODE('ucfg')
movieExportWidth = FOUR_CHAR_CODE('wdth')
movieExportHeight = FOUR_CHAR_CODE('hegt')
movieExportDuration = FOUR_CHAR_CODE('dura')
movieExportVideoFilter = FOUR_CHAR_CODE('iflt')
movieExportTimeScale = FOUR_CHAR_CODE('tmsc')
kQTBrowserInfoCanUseSystemFolderPlugin = (1L << 0)
kQTPreFlightOpenComponent = (1L << 1)
pnotComponentWantsEvents = 1
pnotComponentNeedsNoCache = 2
ShowFilePreviewComponentType = FOUR_CHAR_CODE('pnot')
CreateFilePreviewComponentType = FOUR_CHAR_CODE('pmak')
DataCompressorComponentType = FOUR_CHAR_CODE('dcom')
DataDecompressorComponentType = FOUR_CHAR_CODE('ddec')
AppleDataCompressorSubType = FOUR_CHAR_CODE('adec')
zlibDataCompressorSubType = FOUR_CHAR_CODE('zlib')
kDataHCanRead = 1L << 0
kDataHSpecialRead = 1L << 1
kDataHSpecialReadFile = 1L << 2
kDataHCanWrite = 1L << 3
kDataHSpecialWrite = 1 << 4
kDataHSpecialWriteFile = 1 << 5
kDataHCanStreamingWrite = 1 << 6
kDataHMustCheckDataRef = 1 << 7
kDataRefExtensionChokeSpeed = FOUR_CHAR_CODE('chok')
kDataRefExtensionFileName = FOUR_CHAR_CODE('fnam')
kDataRefExtensionMIMEType = FOUR_CHAR_CODE('mime')
kDataRefExtensionMacOSFileType = FOUR_CHAR_CODE('ftyp')
kDataRefExtensionInitializationData = FOUR_CHAR_CODE('data')
kDataRefExtensionQuickTimeMediaType = FOUR_CHAR_CODE('mtyp')
kDataHChokeToMovieDataRate = 1 << 0
kDataHChokeToParam = 1 << 1
kDataHExtendedSchedule = FOUR_CHAR_CODE('xtnd')
kDataHInfoFlagNeverStreams = 1 << 0
kDataHInfoFlagCanUpdateDataRefs = 1 << 1
kDataHInfoFlagNeedsNetworkBandwidth = 1 << 2
kDataHFileTypeMacOSFileType = FOUR_CHAR_CODE('ftyp')
kDataHFileTypeExtension = FOUR_CHAR_CODE('fext')
kDataHFileTypeMIME = FOUR_CHAR_CODE('mime')
kDataHCreateFileButDontCreateResFile = (1L << 0)
kDataHMovieUsageDoAppendMDAT = 1L << 0
kDataHTempUseSameDirectory = 1L << 0
kDataHTempUseSameVolume = 1L << 1
kDataHTempCreateFile = 1L << 2
kDataHTempOpenFile = 1L << 3
kDataHGetDataRateInfiniteRate = 0x7FFFFFFF
kDataHSetTimeHintsSkipBandwidthRequest = 1 << 0
videoDigitizerComponentType = FOUR_CHAR_CODE('vdig')
vdigInterfaceRev = 2
ntscIn = 0
currentIn = 0
palIn = 1
secamIn = 2
ntscReallyIn = 3
compositeIn = 0
sVideoIn = 1
rgbComponentIn = 2
rgbComponentSyncIn = 3
yuvComponentIn = 4
yuvComponentSyncIn = 5
tvTunerIn = 6
sdiIn = 7
vdPlayThruOff = 0
vdPlayThruOn = 1
vdDigitizerBW = 0
vdDigitizerRGB = 1
vdBroadcastMode = 0
vdVTRMode = 1
vdUseAnyField = 0
vdUseOddField = 1
vdUseEvenField = 2
vdTypeBasic = 0
vdTypeAlpha = 1
vdTypeMask = 2
vdTypeKey = 3
digiInDoesNTSC = 1L << 0
digiInDoesPAL = 1L << 1
digiInDoesSECAM = 1L << 2
digiInDoesGenLock = 1L << 7
digiInDoesComposite = 1L << 8
digiInDoesSVideo = 1L << 9
digiInDoesComponent = 1L << 10
digiInVTR_Broadcast = 1L << 11
digiInDoesColor = 1L << 12
digiInDoesBW = 1L << 13
digiInSignalLock = 1L << 31
digiOutDoes1 = 1L << 0
digiOutDoes2 = 1L << 1
digiOutDoes4 = 1L << 2
digiOutDoes8 = 1L << 3
digiOutDoes16 = 1L << 4
digiOutDoes32 = 1L << 5
digiOutDoesDither = 1L << 6
digiOutDoesStretch = 1L << 7
digiOutDoesShrink = 1L << 8
digiOutDoesMask = 1L << 9
digiOutDoesDouble = 1L << 11
digiOutDoesQuad = 1L << 12
digiOutDoesQuarter = 1L << 13
digiOutDoesSixteenth = 1L << 14
digiOutDoesRotate = 1L << 15
digiOutDoesHorizFlip = 1L << 16
digiOutDoesVertFlip = 1L << 17
digiOutDoesSkew = 1L << 18
digiOutDoesBlend = 1L << 19
digiOutDoesWarp = 1L << 20
digiOutDoesHW_DMA = 1L << 21
digiOutDoesHWPlayThru = 1L << 22
digiOutDoesILUT = 1L << 23
digiOutDoesKeyColor = 1L << 24
digiOutDoesAsyncGrabs = 1L << 25
digiOutDoesUnreadableScreenBits = 1L << 26
digiOutDoesCompress = 1L << 27
digiOutDoesCompressOnly = 1L << 28
digiOutDoesPlayThruDuringCompress = 1L << 29
digiOutDoesCompressPartiallyVisible = 1L << 30
digiOutDoesNotNeedCopyOfCompressData = 1L << 31
dmaDepth1 = 1
dmaDepth2 = 2
dmaDepth4 = 4
dmaDepth8 = 8
dmaDepth16 = 16
dmaDepth32 = 32
dmaDepth2Gray = 64
dmaDepth4Gray = 128
dmaDepth8Gray = 256
kVDIGControlledFrameRate = -1
vdDeviceFlagShowInputsAsDevices = (1 << 0)
vdDeviceFlagHideDevice = (1 << 1)
vdFlagCaptureStarting = (1 << 0)
vdFlagCaptureStopping = (1 << 1)
vdFlagCaptureIsForPreview = (1 << 2)
vdFlagCaptureIsForRecord = (1 << 3)
vdFlagCaptureLowLatency = (1 << 4)
vdFlagCaptureAlwaysUseTimeBase = (1 << 5)
vdFlagCaptureSetSettingsBegin = (1 << 6)
vdFlagCaptureSetSettingsEnd = (1 << 7)
xmlParseComponentType = FOUR_CHAR_CODE('pars')
xmlParseComponentSubType = FOUR_CHAR_CODE('xml ')
xmlIdentifierInvalid = 0
# xmlIdentifierUnrecognized = (long)0xFFFFFFFF
xmlContentTypeInvalid = 0
xmlContentTypeElement = 1
xmlContentTypeCharData = 2
elementFlagAlwaysSelfContained = 1L << 0
elementFlagPreserveWhiteSpace = 1L << 1
xmlParseFlagAllowUppercase = 1L << 0
xmlParseFlagAllowUnquotedAttributeValues = 1L << 1
xmlParseFlagEventParseOnly = 1L << 2
attributeValueKindCharString = 0
attributeValueKindInteger = 1L << 0
attributeValueKindPercent = 1L << 1
attributeValueKindBoolean = 1L << 2
attributeValueKindOnOff = 1L << 3
attributeValueKindColor = 1L << 4
attributeValueKindEnum = 1L << 5
attributeValueKindCaseSensEnum = 1L << 6
MAX_ATTRIBUTE_VALUE_KIND = attributeValueKindCaseSensEnum
nameSpaceIDNone = 0
element_xml = 1
attr_src = 1
SeqGrabComponentType = FOUR_CHAR_CODE('barg')
SeqGrabChannelType = FOUR_CHAR_CODE('sgch')
SeqGrabPanelType = FOUR_CHAR_CODE('sgpn')
SeqGrabCompressionPanelType = FOUR_CHAR_CODE('cmpr')
SeqGrabSourcePanelType = FOUR_CHAR_CODE('sour')
seqGrabToDisk = 1
seqGrabToMemory = 2
seqGrabDontUseTempMemory = 4
seqGrabAppendToFile = 8
seqGrabDontAddMovieResource = 16
seqGrabDontMakeMovie = 32
seqGrabPreExtendFile = 64
seqGrabDataProcIsInterruptSafe = 128
seqGrabDataProcDoesOverlappingReads = 256
seqGrabRecord = 1
seqGrabPreview = 2
seqGrabPlayDuringRecord = 4
seqGrabLowLatencyCapture = 8
seqGrabAlwaysUseTimeBase = 16
seqGrabHasBounds = 1
seqGrabHasVolume = 2
seqGrabHasDiscreteSamples = 4
seqGrabDoNotBufferizeData = 8
seqGrabCanMoveWindowWhileRecording = 16
grabPictOffScreen = 1
grabPictIgnoreClip = 2
grabPictCurrentImage = 4
sgFlagControlledGrab = (1 << 0)
sgFlagAllowNonRGBPixMaps = (1 << 1)
sgDeviceInputNameFlagInputUnavailable = (1 << 0)
sgDeviceNameFlagDeviceUnavailable = (1 << 0)
sgDeviceNameFlagShowInputsAsDevices = (1 << 1)
sgDeviceListWithIcons = (1 << 0)
sgDeviceListDontCheckAvailability = (1 << 1)
sgDeviceListIncludeInputs = (1 << 2)
seqGrabWriteAppend = 0
seqGrabWriteReserve = 1
seqGrabWriteFill = 2
seqGrabUnpause = 0
seqGrabPause = 1
seqGrabPauseForMenu = 3
channelFlagDontOpenResFile = 2
channelFlagHasDependency = 4
sgPanelFlagForPanel = 1
seqGrabSettingsPreviewOnly = 1
channelPlayNormal = 0
channelPlayFast = 1
channelPlayHighQuality = 2
channelPlayAllData = 4
sgSetSettingsBegin = (1 << 0)
sgSetSettingsEnd = (1 << 1)
kSGSmallestDITLSize = -1
kSGLargestDITLSize = -2
sgChannelAtom = FOUR_CHAR_CODE('chan')
sgChannelSettingsAtom = FOUR_CHAR_CODE('ctom')
sgChannelDescription = FOUR_CHAR_CODE('cdsc')
sgChannelSettings = FOUR_CHAR_CODE('cset')
sgDeviceNameType = FOUR_CHAR_CODE('name')
sgDeviceDisplayNameType = FOUR_CHAR_CODE('dnam')
sgDeviceUIDType = FOUR_CHAR_CODE('duid')
sgInputUIDType = FOUR_CHAR_CODE('iuid')
sgUsageType = FOUR_CHAR_CODE('use ')
sgPlayFlagsType = FOUR_CHAR_CODE('plyf')
sgClipType = FOUR_CHAR_CODE('clip')
sgMatrixType = FOUR_CHAR_CODE('mtrx')
sgVolumeType = FOUR_CHAR_CODE('volu')
sgPanelSettingsAtom = FOUR_CHAR_CODE('ptom')
sgPanelDescription = FOUR_CHAR_CODE('pdsc')
sgPanelSettings = FOUR_CHAR_CODE('pset')
sgcSoundCompressionType = FOUR_CHAR_CODE('scmp')
sgcSoundCodecSettingsType = FOUR_CHAR_CODE('cdec')
sgcSoundSampleRateType = FOUR_CHAR_CODE('srat')
sgcSoundChannelCountType = FOUR_CHAR_CODE('schn')
sgcSoundSampleSizeType = FOUR_CHAR_CODE('ssiz')
sgcSoundInputType = FOUR_CHAR_CODE('sinp')
sgcSoundGainType = FOUR_CHAR_CODE('gain')
sgcVideoHueType = FOUR_CHAR_CODE('hue ')
sgcVideoSaturationType = FOUR_CHAR_CODE('satr')
sgcVideoContrastType = FOUR_CHAR_CODE('trst')
sgcVideoSharpnessType = FOUR_CHAR_CODE('shrp')
sgcVideoBrigtnessType = FOUR_CHAR_CODE('brit')
sgcVideoBlackLevelType = FOUR_CHAR_CODE('blkl')
sgcVideoWhiteLevelType = FOUR_CHAR_CODE('whtl')
sgcVideoInputType = FOUR_CHAR_CODE('vinp')
sgcVideoFormatType = FOUR_CHAR_CODE('vstd')
sgcVideoFilterType = FOUR_CHAR_CODE('vflt')
sgcVideoRectType = FOUR_CHAR_CODE('vrct')
sgcVideoDigitizerType = FOUR_CHAR_CODE('vdig')
QTVideoOutputComponentType = FOUR_CHAR_CODE('vout')
QTVideoOutputComponentBaseSubType = FOUR_CHAR_CODE('base')
kQTVideoOutputDontDisplayToUser = 1L << 0
kQTVODisplayModeItem = FOUR_CHAR_CODE('qdmi')
kQTVODimensions = FOUR_CHAR_CODE('dimn')
kQTVOResolution = FOUR_CHAR_CODE('resl')
kQTVORefreshRate = FOUR_CHAR_CODE('refr')
kQTVOPixelType = FOUR_CHAR_CODE('pixl')
kQTVOName = FOUR_CHAR_CODE('name')
kQTVODecompressors = FOUR_CHAR_CODE('deco')
kQTVODecompressorType = FOUR_CHAR_CODE('dety')
kQTVODecompressorContinuous = FOUR_CHAR_CODE('cont')
kQTVODecompressorComponent = FOUR_CHAR_CODE('cmpt')
kClockGetTimeSelect = 0x0001
kClockNewCallBackSelect = 0x0002
kClockDisposeCallBackSelect = 0x0003
kClockCallMeWhenSelect = 0x0004
kClockCancelCallBackSelect = 0x0005
kClockRateChangedSelect = 0x0006
kClockTimeChangedSelect = 0x0007
kClockSetTimeBaseSelect = 0x0008
kClockStartStopChangedSelect = 0x0009
kClockGetRateSelect = 0x000A
kSCGetCompressionExtendedSelect = 0x0001
kSCPositionRectSelect = 0x0002
kSCPositionDialogSelect = 0x0003
kSCSetTestImagePictHandleSelect = 0x0004
kSCSetTestImagePictFileSelect = 0x0005
kSCSetTestImagePixMapSelect = 0x0006
kSCGetBestDeviceRectSelect = 0x0007
kSCRequestImageSettingsSelect = 0x000A
kSCCompressImageSelect = 0x000B
kSCCompressPictureSelect = 0x000C
kSCCompressPictureFileSelect = 0x000D
kSCRequestSequenceSettingsSelect = 0x000E
kSCCompressSequenceBeginSelect = 0x000F
kSCCompressSequenceFrameSelect = 0x0010
kSCCompressSequenceEndSelect = 0x0011
kSCDefaultPictHandleSettingsSelect = 0x0012
kSCDefaultPictFileSettingsSelect = 0x0013
kSCDefaultPixMapSettingsSelect = 0x0014
kSCGetInfoSelect = 0x0015
kSCSetInfoSelect = 0x0016
kSCNewGWorldSelect = 0x0017
kSCSetCompressFlagsSelect = 0x0018
kSCGetCompressFlagsSelect = 0x0019
kSCGetSettingsAsTextSelect = 0x001A
kSCGetSettingsAsAtomContainerSelect = 0x001B
kSCSetSettingsFromAtomContainerSelect = 0x001C
kSCCompressSequenceFrameAsyncSelect = 0x001D
kSCAsyncIdleSelect = 0x001E
kTweenerInitializeSelect = 0x0001
kTweenerDoTweenSelect = 0x0002
kTweenerResetSelect = 0x0003
kTCGetCurrentTimeCodeSelect = 0x0101
kTCGetTimeCodeAtTimeSelect = 0x0102
kTCTimeCodeToStringSelect = 0x0103
kTCTimeCodeToFrameNumberSelect = 0x0104
kTCFrameNumberToTimeCodeSelect = 0x0105
kTCGetSourceRefSelect = 0x0106
kTCSetSourceRefSelect = 0x0107
kTCSetTimeCodeFlagsSelect = 0x0108
kTCGetTimeCodeFlagsSelect = 0x0109
kTCSetDisplayOptionsSelect = 0x010A
kTCGetDisplayOptionsSelect = 0x010B
kMovieImportHandleSelect = 0x0001
kMovieImportFileSelect = 0x0002
kMovieImportSetSampleDurationSelect = 0x0003
kMovieImportSetSampleDescriptionSelect = 0x0004
kMovieImportSetMediaFileSelect = 0x0005
kMovieImportSetDimensionsSelect = 0x0006
kMovieImportSetChunkSizeSelect = 0x0007
kMovieImportSetProgressProcSelect = 0x0008
kMovieImportSetAuxiliaryDataSelect = 0x0009
kMovieImportSetFromScrapSelect = 0x000A
kMovieImportDoUserDialogSelect = 0x000B
kMovieImportSetDurationSelect = 0x000C
kMovieImportGetAuxiliaryDataTypeSelect = 0x000D
kMovieImportValidateSelect = 0x000E
kMovieImportGetFileTypeSelect = 0x000F
kMovieImportDataRefSelect = 0x0010
kMovieImportGetSampleDescriptionSelect = 0x0011
kMovieImportGetMIMETypeListSelect = 0x0012
kMovieImportSetOffsetAndLimitSelect = 0x0013
kMovieImportGetSettingsAsAtomContainerSelect = 0x0014
kMovieImportSetSettingsFromAtomContainerSelect = 0x0015
kMovieImportSetOffsetAndLimit64Select = 0x0016
kMovieImportIdleSelect = 0x0017
kMovieImportValidateDataRefSelect = 0x0018
kMovieImportGetLoadStateSelect = 0x0019
kMovieImportGetMaxLoadedTimeSelect = 0x001A
kMovieImportEstimateCompletionTimeSelect = 0x001B
kMovieImportSetDontBlockSelect = 0x001C
kMovieImportGetDontBlockSelect = 0x001D
kMovieImportSetIdleManagerSelect = 0x001E
kMovieImportSetNewMovieFlagsSelect = 0x001F
kMovieImportGetDestinationMediaTypeSelect = 0x0020
kMovieExportToHandleSelect = 0x0080
kMovieExportToFileSelect = 0x0081
kMovieExportGetAuxiliaryDataSelect = 0x0083
kMovieExportSetProgressProcSelect = 0x0084
kMovieExportSetSampleDescriptionSelect = 0x0085
kMovieExportDoUserDialogSelect = 0x0086
kMovieExportGetCreatorTypeSelect = 0x0087
kMovieExportToDataRefSelect = 0x0088
kMovieExportFromProceduresToDataRefSelect = 0x0089
kMovieExportAddDataSourceSelect = 0x008A
kMovieExportValidateSelect = 0x008B
kMovieExportGetSettingsAsAtomContainerSelect = 0x008C
kMovieExportSetSettingsFromAtomContainerSelect = 0x008D
kMovieExportGetFileNameExtensionSelect = 0x008E
kMovieExportGetShortFileTypeStringSelect = 0x008F
kMovieExportGetSourceMediaTypeSelect = 0x0090
kMovieExportSetGetMoviePropertyProcSelect = 0x0091
kTextExportGetDisplayDataSelect = 0x0100
kTextExportGetTimeFractionSelect = 0x0101
kTextExportSetTimeFractionSelect = 0x0102
kTextExportGetSettingsSelect = 0x0103
kTextExportSetSettingsSelect = 0x0104
kMIDIImportGetSettingsSelect = 0x0100
kMIDIImportSetSettingsSelect = 0x0101
kMovieExportNewGetDataAndPropertiesProcsSelect = 0x0100
kMovieExportDisposeGetDataAndPropertiesProcsSelect = 0x0101
kGraphicsImageImportSetSequenceEnabledSelect = 0x0100
kGraphicsImageImportGetSequenceEnabledSelect = 0x0101
kPreviewShowDataSelect = 0x0001
kPreviewMakePreviewSelect = 0x0002
kPreviewMakePreviewReferenceSelect = 0x0003
kPreviewEventSelect = 0x0004
kDataCodecDecompressSelect = 0x0001
kDataCodecGetCompressBufferSizeSelect = 0x0002
kDataCodecCompressSelect = 0x0003
kDataCodecBeginInterruptSafeSelect = 0x0004
kDataCodecEndInterruptSafeSelect = 0x0005
kDataCodecDecompressPartialSelect = 0x0006
kDataCodecCompressPartialSelect = 0x0007
kDataHGetDataSelect = 0x0002
kDataHPutDataSelect = 0x0003
kDataHFlushDataSelect = 0x0004
kDataHOpenForWriteSelect = 0x0005
kDataHCloseForWriteSelect = 0x0006
kDataHOpenForReadSelect = 0x0008
kDataHCloseForReadSelect = 0x0009
kDataHSetDataRefSelect = 0x000A
kDataHGetDataRefSelect = 0x000B
kDataHCompareDataRefSelect = 0x000C
kDataHTaskSelect = 0x000D
kDataHScheduleDataSelect = 0x000E
kDataHFinishDataSelect = 0x000F
kDataHFlushCacheSelect = 0x0010
kDataHResolveDataRefSelect = 0x0011
kDataHGetFileSizeSelect = 0x0012
kDataHCanUseDataRefSelect = 0x0013
kDataHGetVolumeListSelect = 0x0014
kDataHWriteSelect = 0x0015
kDataHPreextendSelect = 0x0016
kDataHSetFileSizeSelect = 0x0017
kDataHGetFreeSpaceSelect = 0x0018
kDataHCreateFileSelect = 0x0019
kDataHGetPreferredBlockSizeSelect = 0x001A
kDataHGetDeviceIndexSelect = 0x001B
kDataHIsStreamingDataHandlerSelect = 0x001C
kDataHGetDataInBufferSelect = 0x001D
kDataHGetScheduleAheadTimeSelect = 0x001E
kDataHSetCacheSizeLimitSelect = 0x001F
kDataHGetCacheSizeLimitSelect = 0x0020
kDataHGetMovieSelect = 0x0021
kDataHAddMovieSelect = 0x0022
kDataHUpdateMovieSelect = 0x0023
kDataHDoesBufferSelect = 0x0024
kDataHGetFileNameSelect = 0x0025
kDataHGetAvailableFileSizeSelect = 0x0026
kDataHGetMacOSFileTypeSelect = 0x0027
kDataHGetMIMETypeSelect = 0x0028
kDataHSetDataRefWithAnchorSelect = 0x0029
kDataHGetDataRefWithAnchorSelect = 0x002A
kDataHSetMacOSFileTypeSelect = 0x002B
kDataHSetTimeBaseSelect = 0x002C
kDataHGetInfoFlagsSelect = 0x002D
kDataHScheduleData64Select = 0x002E
kDataHWrite64Select = 0x002F
kDataHGetFileSize64Select = 0x0030
kDataHPreextend64Select = 0x0031
kDataHSetFileSize64Select = 0x0032
kDataHGetFreeSpace64Select = 0x0033
kDataHAppend64Select = 0x0034
kDataHReadAsyncSelect = 0x0035
kDataHPollReadSelect = 0x0036
kDataHGetDataAvailabilitySelect = 0x0037
kDataHGetFileSizeAsyncSelect = 0x003A
kDataHGetDataRefAsTypeSelect = 0x003B
kDataHSetDataRefExtensionSelect = 0x003C
kDataHGetDataRefExtensionSelect = 0x003D
kDataHGetMovieWithFlagsSelect = 0x003E
kDataHGetFileTypeOrderingSelect = 0x0040
kDataHCreateFileWithFlagsSelect = 0x0041
kDataHGetMIMETypeAsyncSelect = 0x0042
kDataHGetInfoSelect = 0x0043
kDataHSetIdleManagerSelect = 0x0044
kDataHDeleteFileSelect = 0x0045
kDataHSetMovieUsageFlagsSelect = 0x0046
kDataHUseTemporaryDataRefSelect = 0x0047
kDataHGetTemporaryDataRefCapabilitiesSelect = 0x0048
kDataHRenameFileSelect = 0x0049
kDataHPlaybackHintsSelect = 0x0103
kDataHPlaybackHints64Select = 0x010E
kDataHGetDataRateSelect = 0x0110
kDataHSetTimeHintsSelect = 0x0111
kVDGetMaxSrcRectSelect = 0x0001
kVDGetActiveSrcRectSelect = 0x0002
kVDSetDigitizerRectSelect = 0x0003
kVDGetDigitizerRectSelect = 0x0004
kVDGetVBlankRectSelect = 0x0005
kVDGetMaskPixMapSelect = 0x0006
kVDGetPlayThruDestinationSelect = 0x0008
kVDUseThisCLUTSelect = 0x0009
kVDSetInputGammaValueSelect = 0x000A
kVDGetInputGammaValueSelect = 0x000B
kVDSetBrightnessSelect = 0x000C
kVDGetBrightnessSelect = 0x000D
kVDSetContrastSelect = 0x000E
kVDSetHueSelect = 0x000F
kVDSetSharpnessSelect = 0x0010
kVDSetSaturationSelect = 0x0011
kVDGetContrastSelect = 0x0012
kVDGetHueSelect = 0x0013
kVDGetSharpnessSelect = 0x0014
kVDGetSaturationSelect = 0x0015
kVDGrabOneFrameSelect = 0x0016
kVDGetMaxAuxBufferSelect = 0x0017
kVDGetDigitizerInfoSelect = 0x0019
kVDGetCurrentFlagsSelect = 0x001A
kVDSetKeyColorSelect = 0x001B
kVDGetKeyColorSelect = 0x001C
kVDAddKeyColorSelect = 0x001D
kVDGetNextKeyColorSelect = 0x001E
kVDSetKeyColorRangeSelect = 0x001F
kVDGetKeyColorRangeSelect = 0x0020
kVDSetDigitizerUserInterruptSelect = 0x0021
kVDSetInputColorSpaceModeSelect = 0x0022
kVDGetInputColorSpaceModeSelect = 0x0023
kVDSetClipStateSelect = 0x0024
kVDGetClipStateSelect = 0x0025
kVDSetClipRgnSelect = 0x0026
kVDClearClipRgnSelect = 0x0027
kVDGetCLUTInUseSelect = 0x0028
kVDSetPLLFilterTypeSelect = 0x0029
kVDGetPLLFilterTypeSelect = 0x002A
kVDGetMaskandValueSelect = 0x002B
kVDSetMasterBlendLevelSelect = 0x002C
kVDSetPlayThruDestinationSelect = 0x002D
kVDSetPlayThruOnOffSelect = 0x002E
kVDSetFieldPreferenceSelect = 0x002F
kVDGetFieldPreferenceSelect = 0x0030
kVDPreflightDestinationSelect = 0x0032
kVDPreflightGlobalRectSelect = 0x0033
kVDSetPlayThruGlobalRectSelect = 0x0034
kVDSetInputGammaRecordSelect = 0x0035
kVDGetInputGammaRecordSelect = 0x0036
kVDSetBlackLevelValueSelect = 0x0037
kVDGetBlackLevelValueSelect = 0x0038
kVDSetWhiteLevelValueSelect = 0x0039
kVDGetWhiteLevelValueSelect = 0x003A
kVDGetVideoDefaultsSelect = 0x003B
kVDGetNumberOfInputsSelect = 0x003C
kVDGetInputFormatSelect = 0x003D
kVDSetInputSelect = 0x003E
kVDGetInputSelect = 0x003F
kVDSetInputStandardSelect = 0x0040
kVDSetupBuffersSelect = 0x0041
kVDGrabOneFrameAsyncSelect = 0x0042
kVDDoneSelect = 0x0043
kVDSetCompressionSelect = 0x0044
kVDCompressOneFrameAsyncSelect = 0x0045
kVDCompressDoneSelect = 0x0046
kVDReleaseCompressBufferSelect = 0x0047
kVDGetImageDescriptionSelect = 0x0048
kVDResetCompressSequenceSelect = 0x0049
kVDSetCompressionOnOffSelect = 0x004A
kVDGetCompressionTypesSelect = 0x004B
kVDSetTimeBaseSelect = 0x004C
kVDSetFrameRateSelect = 0x004D
kVDGetDataRateSelect = 0x004E
kVDGetSoundInputDriverSelect = 0x004F
kVDGetDMADepthsSelect = 0x0050
kVDGetPreferredTimeScaleSelect = 0x0051
kVDReleaseAsyncBuffersSelect = 0x0052
kVDSetDataRateSelect = 0x0054
kVDGetTimeCodeSelect = 0x0055
kVDUseSafeBuffersSelect = 0x0056
kVDGetSoundInputSourceSelect = 0x0057
kVDGetCompressionTimeSelect = 0x0058
kVDSetPreferredPacketSizeSelect = 0x0059
kVDSetPreferredImageDimensionsSelect = 0x005A
kVDGetPreferredImageDimensionsSelect = 0x005B
kVDGetInputNameSelect = 0x005C
kVDSetDestinationPortSelect = 0x005D
kVDGetDeviceNameAndFlagsSelect = 0x005E
kVDCaptureStateChangingSelect = 0x005F
kVDGetUniqueIDsSelect = 0x0060
kVDSelectUniqueIDsSelect = 0x0061
kXMLParseDataRefSelect = 0x0001
kXMLParseFileSelect = 0x0002
kXMLParseDisposeXMLDocSelect = 0x0003
kXMLParseGetDetailedParseErrorSelect = 0x0004
kXMLParseAddElementSelect = 0x0005
kXMLParseAddAttributeSelect = 0x0006
kXMLParseAddMultipleAttributesSelect = 0x0007
kXMLParseAddAttributeAndValueSelect = 0x0008
kXMLParseAddMultipleAttributesAndValuesSelect = 0x0009
kXMLParseAddAttributeValueKindSelect = 0x000A
kXMLParseAddNameSpaceSelect = 0x000B
kXMLParseSetOffsetAndLimitSelect = 0x000C
kXMLParseSetEventParseRefConSelect = 0x000D
kXMLParseSetStartDocumentHandlerSelect = 0x000E
kXMLParseSetEndDocumentHandlerSelect = 0x000F
kXMLParseSetStartElementHandlerSelect = 0x0010
kXMLParseSetEndElementHandlerSelect = 0x0011
kXMLParseSetCharDataHandlerSelect = 0x0012
kXMLParseSetPreprocessInstructionHandlerSelect = 0x0013
kXMLParseSetCommentHandlerSelect = 0x0014
kXMLParseSetCDataHandlerSelect = 0x0015
kSGInitializeSelect = 0x0001
kSGSetDataOutputSelect = 0x0002
kSGGetDataOutputSelect = 0x0003
kSGSetGWorldSelect = 0x0004
kSGGetGWorldSelect = 0x0005
kSGNewChannelSelect = 0x0006
kSGDisposeChannelSelect = 0x0007
kSGStartPreviewSelect = 0x0010
kSGStartRecordSelect = 0x0011
kSGIdleSelect = 0x0012
kSGStopSelect = 0x0013
kSGPauseSelect = 0x0014
kSGPrepareSelect = 0x0015
kSGReleaseSelect = 0x0016
kSGGetMovieSelect = 0x0017
kSGSetMaximumRecordTimeSelect = 0x0018
kSGGetMaximumRecordTimeSelect = 0x0019
kSGGetStorageSpaceRemainingSelect = 0x001A
kSGGetTimeRemainingSelect = 0x001B
kSGGrabPictSelect = 0x001C
kSGGetLastMovieResIDSelect = 0x001D
kSGSetFlagsSelect = 0x001E
kSGGetFlagsSelect = 0x001F
kSGSetDataProcSelect = 0x0020
kSGNewChannelFromComponentSelect = 0x0021
kSGDisposeDeviceListSelect = 0x0022
kSGAppendDeviceListToMenuSelect = 0x0023
kSGSetSettingsSelect = 0x0024
kSGGetSettingsSelect = 0x0025
kSGGetIndChannelSelect = 0x0026
kSGUpdateSelect = 0x0027
kSGGetPauseSelect = 0x0028
kSGSettingsDialogSelect = 0x0029
kSGGetAlignmentProcSelect = 0x002A
kSGSetChannelSettingsSelect = 0x002B
kSGGetChannelSettingsSelect = 0x002C
kSGGetModeSelect = 0x002D
kSGSetDataRefSelect = 0x002E
kSGGetDataRefSelect = 0x002F
kSGNewOutputSelect = 0x0030
kSGDisposeOutputSelect = 0x0031
kSGSetOutputFlagsSelect = 0x0032
kSGSetChannelOutputSelect = 0x0033
kSGGetDataOutputStorageSpaceRemainingSelect = 0x0034
kSGHandleUpdateEventSelect = 0x0035
kSGSetOutputNextOutputSelect = 0x0036
kSGGetOutputNextOutputSelect = 0x0037
kSGSetOutputMaximumOffsetSelect = 0x0038
kSGGetOutputMaximumOffsetSelect = 0x0039
kSGGetOutputDataReferenceSelect = 0x003A
kSGWriteExtendedMovieDataSelect = 0x003B
kSGGetStorageSpaceRemaining64Select = 0x003C
kSGGetDataOutputStorageSpaceRemaining64Select = 0x003D
kSGWriteMovieDataSelect = 0x0100
kSGAddFrameReferenceSelect = 0x0101
kSGGetNextFrameReferenceSelect = 0x0102
kSGGetTimeBaseSelect = 0x0103
kSGSortDeviceListSelect = 0x0104
kSGAddMovieDataSelect = 0x0105
kSGChangedSourceSelect = 0x0106
kSGAddExtendedFrameReferenceSelect = 0x0107
kSGGetNextExtendedFrameReferenceSelect = 0x0108
kSGAddExtendedMovieDataSelect = 0x0109
kSGAddOutputDataRefToMediaSelect = 0x010A
kSGSetSettingsSummarySelect = 0x010B
kSGSetChannelUsageSelect = 0x0080
kSGGetChannelUsageSelect = 0x0081
kSGSetChannelBoundsSelect = 0x0082
kSGGetChannelBoundsSelect = 0x0083
kSGSetChannelVolumeSelect = 0x0084
kSGGetChannelVolumeSelect = 0x0085
kSGGetChannelInfoSelect = 0x0086
kSGSetChannelPlayFlagsSelect = 0x0087
kSGGetChannelPlayFlagsSelect = 0x0088
kSGSetChannelMaxFramesSelect = 0x0089
kSGGetChannelMaxFramesSelect = 0x008A
kSGSetChannelRefConSelect = 0x008B
kSGSetChannelClipSelect = 0x008C
kSGGetChannelClipSelect = 0x008D
kSGGetChannelSampleDescriptionSelect = 0x008E
kSGGetChannelDeviceListSelect = 0x008F
kSGSetChannelDeviceSelect = 0x0090
kSGSetChannelMatrixSelect = 0x0091
kSGGetChannelMatrixSelect = 0x0092
kSGGetChannelTimeScaleSelect = 0x0093
kSGChannelPutPictureSelect = 0x0094
kSGChannelSetRequestedDataRateSelect = 0x0095
kSGChannelGetRequestedDataRateSelect = 0x0096
kSGChannelSetDataSourceNameSelect = 0x0097
kSGChannelGetDataSourceNameSelect = 0x0098
kSGChannelSetCodecSettingsSelect = 0x0099
kSGChannelGetCodecSettingsSelect = 0x009A
kSGGetChannelTimeBaseSelect = 0x009B
kSGGetChannelRefConSelect = 0x009C
kSGGetChannelDeviceAndInputNamesSelect = 0x009D
kSGSetChannelDeviceInputSelect = 0x009E
kSGSetChannelSettingsStateChangingSelect = 0x009F
kSGInitChannelSelect = 0x0180
kSGWriteSamplesSelect = 0x0181
kSGGetDataRateSelect = 0x0182
kSGAlignChannelRectSelect = 0x0183
kSGPanelGetDitlSelect = 0x0200
kSGPanelGetTitleSelect = 0x0201
kSGPanelCanRunSelect = 0x0202
kSGPanelInstallSelect = 0x0203
kSGPanelEventSelect = 0x0204
kSGPanelItemSelect = 0x0205
kSGPanelRemoveSelect = 0x0206
kSGPanelSetGrabberSelect = 0x0207
kSGPanelSetResFileSelect = 0x0208
kSGPanelGetSettingsSelect = 0x0209
kSGPanelSetSettingsSelect = 0x020A
kSGPanelValidateInputSelect = 0x020B
kSGPanelSetEventFilterSelect = 0x020C
kSGPanelGetDITLForSizeSelect = 0x020D
kSGGetSrcVideoBoundsSelect = 0x0100
kSGSetVideoRectSelect = 0x0101
kSGGetVideoRectSelect = 0x0102
kSGGetVideoCompressorTypeSelect = 0x0103
kSGSetVideoCompressorTypeSelect = 0x0104
kSGSetVideoCompressorSelect = 0x0105
kSGGetVideoCompressorSelect = 0x0106
kSGGetVideoDigitizerComponentSelect = 0x0107
kSGSetVideoDigitizerComponentSelect = 0x0108
kSGVideoDigitizerChangedSelect = 0x0109
kSGSetVideoBottlenecksSelect = 0x010A
kSGGetVideoBottlenecksSelect = 0x010B
kSGGrabFrameSelect = 0x010C
kSGGrabFrameCompleteSelect = 0x010D
kSGDisplayFrameSelect = 0x010E
kSGCompressFrameSelect = 0x010F
kSGCompressFrameCompleteSelect = 0x0110
kSGAddFrameSelect = 0x0111
kSGTransferFrameForCompressSelect = 0x0112
kSGSetCompressBufferSelect = 0x0113
kSGGetCompressBufferSelect = 0x0114
kSGGetBufferInfoSelect = 0x0115
kSGSetUseScreenBufferSelect = 0x0116
kSGGetUseScreenBufferSelect = 0x0117
kSGGrabCompressCompleteSelect = 0x0118
kSGDisplayCompressSelect = 0x0119
kSGSetFrameRateSelect = 0x011A
kSGGetFrameRateSelect = 0x011B
kSGSetPreferredPacketSizeSelect = 0x0121
kSGGetPreferredPacketSizeSelect = 0x0122
kSGSetUserVideoCompressorListSelect = 0x0123
kSGGetUserVideoCompressorListSelect = 0x0124
kSGSetSoundInputDriverSelect = 0x0100
kSGGetSoundInputDriverSelect = 0x0101
kSGSoundInputDriverChangedSelect = 0x0102
kSGSetSoundRecordChunkSizeSelect = 0x0103
kSGGetSoundRecordChunkSizeSelect = 0x0104
kSGSetSoundInputRateSelect = 0x0105
kSGGetSoundInputRateSelect = 0x0106
kSGSetSoundInputParametersSelect = 0x0107
kSGGetSoundInputParametersSelect = 0x0108
kSGSetAdditionalSoundRatesSelect = 0x0109
kSGGetAdditionalSoundRatesSelect = 0x010A
kSGSetFontNameSelect = 0x0100
kSGSetFontSizeSelect = 0x0101
kSGSetTextForeColorSelect = 0x0102
kSGSetTextBackColorSelect = 0x0103
kSGSetJustificationSelect = 0x0104
kSGGetTextReturnToSpaceValueSelect = 0x0105
kSGSetTextReturnToSpaceValueSelect = 0x0106
kSGGetInstrumentSelect = 0x0100
kSGSetInstrumentSelect = 0x0101
kQTVideoOutputGetDisplayModeListSelect = 0x0001
kQTVideoOutputGetCurrentClientNameSelect = 0x0002
kQTVideoOutputSetClientNameSelect = 0x0003
kQTVideoOutputGetClientNameSelect = 0x0004
kQTVideoOutputBeginSelect = 0x0005
kQTVideoOutputEndSelect = 0x0006
kQTVideoOutputSetDisplayModeSelect = 0x0007
kQTVideoOutputGetDisplayModeSelect = 0x0008
kQTVideoOutputCustomConfigureDisplaySelect = 0x0009
kQTVideoOutputSaveStateSelect = 0x000A
kQTVideoOutputRestoreStateSelect = 0x000B
kQTVideoOutputGetGWorldSelect = 0x000C
kQTVideoOutputGetGWorldParametersSelect = 0x000D
kQTVideoOutputGetIndSoundOutputSelect = 0x000E
kQTVideoOutputGetClockSelect = 0x000F
kQTVideoOutputSetEchoPortSelect = 0x0010
kQTVideoOutputGetIndImageDecompressorSelect = 0x0011
kQTVideoOutputBaseSetEchoPortSelect = 0x0012
handlerHasSpatial = 1 << 0
handlerCanClip = 1 << 1
handlerCanMatte = 1 << 2
handlerCanTransferMode = 1 << 3
handlerNeedsBuffer = 1 << 4
handlerNoIdle = 1 << 5
handlerNoScheduler = 1 << 6
handlerWantsTime = 1 << 7
handlerCGrafPortOnly = 1 << 8
handlerCanSend = 1 << 9
handlerCanHandleComplexMatrix = 1 << 10
handlerWantsDestinationPixels = 1 << 11
handlerCanSendImageData = 1 << 12
handlerCanPicSave = 1 << 13
mMustDraw = 1 << 3
mAtEnd = 1 << 4
mPreflightDraw = 1 << 5
mSyncDrawing = 1 << 6
mPrecompositeOnly = 1 << 9
mSoundOnly = 1 << 10
mDoIdleActionsBeforeDraws = 1 << 11
mDisableIdleActions = 1 << 12
mDidDraw = 1 << 0
mNeedsToDraw = 1 << 2
mDrawAgain = 1 << 3
mPartialDraw = 1 << 4
mWantIdleActions = 1 << 5
forceUpdateRedraw = 1 << 0
forceUpdateNewBuffer = 1 << 1
mHitTestBounds = 1L << 0
mHitTestImage = 1L << 1
mHitTestInvisible = 1L << 2
mHitTestIsClick = 1L << 3
mOpaque = 1L << 0
mInvisible = 1L << 1
kMediaQTIdleFrequencySelector = FOUR_CHAR_CODE('idfq')
kMediaVideoParamBrightness = 1
kMediaVideoParamContrast = 2
kMediaVideoParamHue = 3
kMediaVideoParamSharpness = 4
kMediaVideoParamSaturation = 5
kMediaVideoParamBlackLevel = 6
kMediaVideoParamWhiteLevel = 7
kMHInfoEncodedFrameRate = FOUR_CHAR_CODE('orat')
kEmptyPurgableChunksOverAllowance = 1
kCallComponentExecuteWiredActionSelect = -9
kMediaSetChunkManagementFlagsSelect = 0x0415
kMediaGetChunkManagementFlagsSelect = 0x0416
kMediaSetPurgeableChunkMemoryAllowanceSelect = 0x0417
kMediaGetPurgeableChunkMemoryAllowanceSelect = 0x0418
kMediaEmptyAllPurgeableChunksSelect = 0x0419
kMediaInitializeSelect = 0x0501
kMediaSetHandlerCapabilitiesSelect = 0x0502
kMediaIdleSelect = 0x0503
kMediaGetMediaInfoSelect = 0x0504
kMediaPutMediaInfoSelect = 0x0505
kMediaSetActiveSelect = 0x0506
kMediaSetRateSelect = 0x0507
kMediaGGetStatusSelect = 0x0508
kMediaTrackEditedSelect = 0x0509
kMediaSetMediaTimeScaleSelect = 0x050A
kMediaSetMovieTimeScaleSelect = 0x050B
kMediaSetGWorldSelect = 0x050C
kMediaSetDimensionsSelect = 0x050D
kMediaSetClipSelect = 0x050E
kMediaSetMatrixSelect = 0x050F
kMediaGetTrackOpaqueSelect = 0x0510
kMediaSetGraphicsModeSelect = 0x0511
kMediaGetGraphicsModeSelect = 0x0512
kMediaGSetVolumeSelect = 0x0513
kMediaSetSoundBalanceSelect = 0x0514
kMediaGetSoundBalanceSelect = 0x0515
kMediaGetNextBoundsChangeSelect = 0x0516
kMediaGetSrcRgnSelect = 0x0517
kMediaPrerollSelect = 0x0518
kMediaSampleDescriptionChangedSelect = 0x0519
kMediaHasCharacteristicSelect = 0x051A
kMediaGetOffscreenBufferSizeSelect = 0x051B
kMediaSetHintsSelect = 0x051C
kMediaGetNameSelect = 0x051D
kMediaForceUpdateSelect = 0x051E
kMediaGetDrawingRgnSelect = 0x051F
kMediaGSetActiveSegmentSelect = 0x0520
kMediaInvalidateRegionSelect = 0x0521
kMediaGetNextStepTimeSelect = 0x0522
kMediaSetNonPrimarySourceDataSelect = 0x0523
kMediaChangedNonPrimarySourceSelect = 0x0524
kMediaTrackReferencesChangedSelect = 0x0525
kMediaGetSampleDataPointerSelect = 0x0526
kMediaReleaseSampleDataPointerSelect = 0x0527
kMediaTrackPropertyAtomChangedSelect = 0x0528
kMediaSetTrackInputMapReferenceSelect = 0x0529
kMediaSetVideoParamSelect = 0x052B
kMediaGetVideoParamSelect = 0x052C
kMediaCompareSelect = 0x052D
kMediaGetClockSelect = 0x052E
kMediaSetSoundOutputComponentSelect = 0x052F
kMediaGetSoundOutputComponentSelect = 0x0530
kMediaSetSoundLocalizationDataSelect = 0x0531
kMediaGetInvalidRegionSelect = 0x053C
kMediaSampleDescriptionB2NSelect = 0x053E
kMediaSampleDescriptionN2BSelect = 0x053F
kMediaQueueNonPrimarySourceDataSelect = 0x0540
kMediaFlushNonPrimarySourceDataSelect = 0x0541
kMediaGetURLLinkSelect = 0x0543
kMediaMakeMediaTimeTableSelect = 0x0545
kMediaHitTestForTargetRefConSelect = 0x0546
kMediaHitTestTargetRefConSelect = 0x0547
kMediaGetActionsForQTEventSelect = 0x0548
kMediaDisposeTargetRefConSelect = 0x0549
kMediaTargetRefConsEqualSelect = 0x054A
kMediaSetActionsCallbackSelect = 0x054B
kMediaPrePrerollBeginSelect = 0x054C
kMediaPrePrerollCancelSelect = 0x054D
kMediaEnterEmptyEditSelect = 0x054F
kMediaCurrentMediaQueuedDataSelect = 0x0550
kMediaGetEffectiveVolumeSelect = 0x0551
kMediaResolveTargetRefConSelect = 0x0552
kMediaGetSoundLevelMeteringEnabledSelect = 0x0553
kMediaSetSoundLevelMeteringEnabledSelect = 0x0554
kMediaGetSoundLevelMeterInfoSelect = 0x0555
kMediaGetEffectiveSoundBalanceSelect = 0x0556
kMediaSetScreenLockSelect = 0x0557
kMediaSetDoMCActionCallbackSelect = 0x0558
kMediaGetErrorStringSelect = 0x0559
kMediaGetSoundEqualizerBandsSelect = 0x055A
kMediaSetSoundEqualizerBandsSelect = 0x055B
kMediaGetSoundEqualizerBandLevelsSelect = 0x055C
kMediaDoIdleActionsSelect = 0x055D
kMediaSetSoundBassAndTrebleSelect = 0x055E
kMediaGetSoundBassAndTrebleSelect = 0x055F
kMediaTimeBaseChangedSelect = 0x0560
kMediaMCIsPlayerEventSelect = 0x0561
kMediaGetMediaLoadStateSelect = 0x0562
kMediaVideoOutputChangedSelect = 0x0563
kMediaEmptySampleCacheSelect = 0x0564
kMediaGetPublicInfoSelect = 0x0565
kMediaSetPublicInfoSelect = 0x0566
kMediaGetUserPreferredCodecsSelect = 0x0567
kMediaSetUserPreferredCodecsSelect = 0x0568
kMediaRefConSetPropertySelect = 0x0569
kMediaRefConGetPropertySelect = 0x056A
kMediaNavigateTargetRefConSelect = 0x056B
kMediaGGetIdleManagerSelect = 0x056C
kMediaGSetIdleManagerSelect = 0x056D
kaiToneDescType = FOUR_CHAR_CODE('tone')
kaiNoteRequestInfoType = FOUR_CHAR_CODE('ntrq')
kaiKnobListType = FOUR_CHAR_CODE('knbl')
kaiKeyRangeInfoType = FOUR_CHAR_CODE('sinf')
kaiSampleDescType = FOUR_CHAR_CODE('sdsc')
kaiSampleInfoType = FOUR_CHAR_CODE('smin')
kaiSampleDataType = FOUR_CHAR_CODE('sdat')
kaiSampleDataQUIDType = FOUR_CHAR_CODE('quid')
kaiInstInfoType = FOUR_CHAR_CODE('iinf')
kaiPictType = FOUR_CHAR_CODE('pict')
kaiWriterType = FOUR_CHAR_CODE('\xa9wrt')
kaiCopyrightType = FOUR_CHAR_CODE('\xa9cpy')
kaiOtherStrType = FOUR_CHAR_CODE('str ')
kaiInstrumentRefType = FOUR_CHAR_CODE('iref')
kaiInstGMQualityType = FOUR_CHAR_CODE('qual')
kaiLibraryInfoType = FOUR_CHAR_CODE('linf')
kaiLibraryDescType = FOUR_CHAR_CODE('ldsc')
kInstKnobMissingUnknown = 0
kInstKnobMissingDefault = (1 << 0)
kMusicLoopTypeNormal = 0
kMusicLoopTypePalindrome = 1
instSamplePreProcessFlag = 1 << 0
kQTMIDIComponentType = FOUR_CHAR_CODE('midi')
kOMSComponentSubType = FOUR_CHAR_CODE('OMS ')
kFMSComponentSubType = FOUR_CHAR_CODE('FMS ')
kMIDIManagerComponentSubType = FOUR_CHAR_CODE('mmgr')
kOSXMIDIComponentSubType = FOUR_CHAR_CODE('osxm')
kMusicPacketPortLost = 1
kMusicPacketPortFound = 2
kMusicPacketTimeGap = 3
kAppleSysexID = 0x11
kAppleSysexCmdSampleSize = 0x0001
kAppleSysexCmdSampleBreak = 0x0002
kAppleSysexCmdAtomicInstrument = 0x0010
kAppleSysexCmdDeveloper = 0x7F00
kSynthesizerConnectionFMS = 1
kSynthesizerConnectionMMgr = 2
kSynthesizerConnectionOMS = 4
kSynthesizerConnectionQT = 8
kSynthesizerConnectionOSXMIDI = 16
kSynthesizerConnectionUnavailable = 256
kMusicComponentType = FOUR_CHAR_CODE('musi')
kInstrumentComponentType = FOUR_CHAR_CODE('inst')
kSoftSynthComponentSubType = FOUR_CHAR_CODE('ss  ')
kGMSynthComponentSubType = FOUR_CHAR_CODE('gm  ')
kSynthesizerDynamicVoice = 1 << 0
kSynthesizerUsesMIDIPort = 1 << 1
kSynthesizerMicrotone = 1 << 2
kSynthesizerHasSamples = 1 << 3
kSynthesizerMixedDrums = 1 << 4
kSynthesizerSoftware = 1 << 5
kSynthesizerHardware = 1 << 6
kSynthesizerDynamicChannel = 1 << 7
kSynthesizerHogsSystemChannel = 1 << 8
kSynthesizerHasSystemChannel = 1 << 9
kSynthesizerSlowSetPart = 1 << 10
kSynthesizerOffline = 1 << 12
kSynthesizerGM = 1 << 14
kSynthesizerDLS = 1 << 15
kSynthesizerSoundLocalization = 1 << 16
kControllerModulationWheel = 1
kControllerBreath = 2
kControllerFoot = 4
kControllerPortamentoTime = 5
kControllerVolume = 7
kControllerBalance = 8
kControllerPan = 10
kControllerExpression = 11
kControllerLever1 = 16
kControllerLever2 = 17
kControllerLever3 = 18
kControllerLever4 = 19
kControllerLever5 = 80
kControllerLever6 = 81
kControllerLever7 = 82
kControllerLever8 = 83
kControllerPitchBend = 32
kControllerAfterTouch = 33
kControllerPartTranspose = 40
kControllerTuneTranspose = 41
kControllerPartVolume = 42
kControllerTuneVolume = 43
kControllerSustain = 64
kControllerPortamento = 65
kControllerSostenuto = 66
kControllerSoftPedal = 67
kControllerReverb = 91
kControllerTremolo = 92
kControllerChorus = 93
kControllerCeleste = 94
kControllerPhaser = 95
kControllerEditPart = 113
kControllerMasterTune = 114
kControllerMasterTranspose = 114
kControllerMasterVolume = 115
kControllerMasterCPULoad = 116
kControllerMasterPolyphony = 117
kControllerMasterFeatures = 118
kQTMSKnobStartID = 0x02000000
kQTMSKnobVolumeAttackTimeID = 0x02000001
kQTMSKnobVolumeDecayTimeID = 0x02000002
kQTMSKnobVolumeSustainLevelID = 0x02000003
kQTMSKnobVolumeRelease1RateID = 0x02000004
kQTMSKnobVolumeDecayKeyScalingID = 0x02000005
kQTMSKnobVolumeReleaseTimeID = 0x02000006
kQTMSKnobVolumeLFODelayID = 0x02000007
kQTMSKnobVolumeLFORampTimeID = 0x02000008
kQTMSKnobVolumeLFOPeriodID = 0x02000009
kQTMSKnobVolumeLFOShapeID = 0x0200000A
kQTMSKnobVolumeLFODepthID = 0x0200000B
kQTMSKnobVolumeOverallID = 0x0200000C
kQTMSKnobVolumeVelocity127ID = 0x0200000D
kQTMSKnobVolumeVelocity96ID = 0x0200000E
kQTMSKnobVolumeVelocity64ID = 0x0200000F
kQTMSKnobVolumeVelocity32ID = 0x02000010
kQTMSKnobVolumeVelocity16ID = 0x02000011
kQTMSKnobPitchTransposeID = 0x02000012
kQTMSKnobPitchLFODelayID = 0x02000013
kQTMSKnobPitchLFORampTimeID = 0x02000014
kQTMSKnobPitchLFOPeriodID = 0x02000015
kQTMSKnobPitchLFOShapeID = 0x02000016
kQTMSKnobPitchLFODepthID = 0x02000017
kQTMSKnobPitchLFOQuantizeID = 0x02000018
kQTMSKnobStereoDefaultPanID = 0x02000019
kQTMSKnobStereoPositionKeyScalingID = 0x0200001A
kQTMSKnobPitchLFOOffsetID = 0x0200001B
kQTMSKnobExclusionGroupID = 0x0200001C
kQTMSKnobSustainTimeID = 0x0200001D
kQTMSKnobSustainInfiniteID = 0x0200001E
kQTMSKnobVolumeLFOStereoID = 0x0200001F
kQTMSKnobVelocityLowID = 0x02000020
kQTMSKnobVelocityHighID = 0x02000021
kQTMSKnobVelocitySensitivityID = 0x02000022
kQTMSKnobPitchSensitivityID = 0x02000023
kQTMSKnobVolumeLFODepthFromWheelID = 0x02000024
kQTMSKnobPitchLFODepthFromWheelID = 0x02000025
kQTMSKnobVolumeExpOptionsID = 0x02000026
kQTMSKnobEnv1AttackTimeID = 0x02000027
kQTMSKnobEnv1DecayTimeID = 0x02000028
kQTMSKnobEnv1SustainLevelID = 0x02000029
kQTMSKnobEnv1SustainTimeID = 0x0200002A
kQTMSKnobEnv1SustainInfiniteID = 0x0200002B
kQTMSKnobEnv1ReleaseTimeID = 0x0200002C
kQTMSKnobEnv1ExpOptionsID = 0x0200002D
kQTMSKnobEnv2AttackTimeID = 0x0200002E
kQTMSKnobEnv2DecayTimeID = 0x0200002F
kQTMSKnobEnv2SustainLevelID = 0x02000030
kQTMSKnobEnv2SustainTimeID = 0x02000031
kQTMSKnobEnv2SustainInfiniteID = 0x02000032
kQTMSKnobEnv2ReleaseTimeID = 0x02000033
kQTMSKnobEnv2ExpOptionsID = 0x02000034
kQTMSKnobPitchEnvelopeID = 0x02000035
kQTMSKnobPitchEnvelopeDepthID = 0x02000036
kQTMSKnobFilterKeyFollowID = 0x02000037
kQTMSKnobFilterTransposeID = 0x02000038
kQTMSKnobFilterQID = 0x02000039
kQTMSKnobFilterFrequencyEnvelopeID = 0x0200003A
kQTMSKnobFilterFrequencyEnvelopeDepthID = 0x0200003B
kQTMSKnobFilterQEnvelopeID = 0x0200003C
kQTMSKnobFilterQEnvelopeDepthID = 0x0200003D
kQTMSKnobReverbThresholdID = 0x0200003E
kQTMSKnobVolumeAttackVelScalingID = 0x0200003F
kQTMSKnobLastIDPlus1 = 0x02000040
kControllerMaximum = 0x00007FFF
# kControllerMinimum = (long)0xFFFF8000
kVoiceCountDynamic = -1
kFirstGMInstrument = 0x00000001
kLastGMInstrument = 0x00000080
kFirstGSInstrument = 0x00000081
kLastGSInstrument = 0x00003FFF
kFirstDrumkit = 0x00004000
kLastDrumkit = 0x00004080
kFirstROMInstrument = 0x00008000
kLastROMInstrument = 0x0000FFFF
kFirstUserInstrument = 0x00010000
kLastUserInstrument = 0x0001FFFF
kInstrumentMatchSynthesizerType = 1
kInstrumentMatchSynthesizerName = 2
kInstrumentMatchName = 4
kInstrumentMatchNumber = 8
kInstrumentMatchGMNumber = 16
kInstrumentMatchGSNumber = 32
kKnobBasic = 8
kKnobReadOnly = 16
kKnobInterruptUnsafe = 32
kKnobKeyrangeOverride = 64
kKnobGroupStart = 128
kKnobFixedPoint8 = 1024
kKnobFixedPoint16 = 2048
kKnobTypeNumber = 0 << 12
kKnobTypeGroupName = 1 << 12
kKnobTypeBoolean = 2 << 12
kKnobTypeNote = 3 << 12
kKnobTypePan = 4 << 12
kKnobTypeInstrument = 5 << 12
kKnobTypeSetting = 6 << 12
kKnobTypeMilliseconds = 7 << 12
kKnobTypePercentage = 8 << 12
kKnobTypeHertz = 9 << 12
kKnobTypeButton = 10 << 12
kUnknownKnobValue = 0x7FFFFFFF
kDefaultKnobValue = 0x7FFFFFFE
notImplementedMusicErr = (0x80000000 | (0xFFFF & (notImplementedMusicOSErr)))
cantSendToSynthesizerErr = (0x80000000 | (0xFFFF & (cantSendToSynthesizerOSErr)))
cantReceiveFromSynthesizerErr = (0x80000000 | (0xFFFF & (cantReceiveFromSynthesizerOSErr)))
illegalVoiceAllocationErr = (0x80000000 | (0xFFFF & (illegalVoiceAllocationOSErr)))
illegalPartErr = (0x80000000 | (0xFFFF & (illegalPartOSErr)))
illegalChannelErr = (0x80000000 | (0xFFFF & (illegalChannelOSErr)))
illegalKnobErr = (0x80000000 | (0xFFFF & (illegalKnobOSErr)))
illegalKnobValueErr = (0x80000000 | (0xFFFF & (illegalKnobValueOSErr)))
illegalInstrumentErr = (0x80000000 | (0xFFFF & (illegalInstrumentOSErr)))
illegalControllerErr = (0x80000000 | (0xFFFF & (illegalControllerOSErr)))
midiManagerAbsentErr = (0x80000000 | (0xFFFF & (midiManagerAbsentOSErr)))
synthesizerNotRespondingErr = (0x80000000 | (0xFFFF & (synthesizerNotRespondingOSErr)))
synthesizerErr = (0x80000000 | (0xFFFF & (synthesizerOSErr)))
illegalNoteChannelErr = (0x80000000 | (0xFFFF & (illegalNoteChannelOSErr)))
noteChannelNotAllocatedErr = (0x80000000 | (0xFFFF & (noteChannelNotAllocatedOSErr)))
tunePlayerFullErr = (0x80000000 | (0xFFFF & (tunePlayerFullOSErr)))
tuneParseErr = (0x80000000 | (0xFFFF & (tuneParseOSErr)))
kGetAtomicInstNoExpandedSamples = 1 << 0
kGetAtomicInstNoOriginalSamples = 1 << 1
kGetAtomicInstNoSamples = kGetAtomicInstNoExpandedSamples | kGetAtomicInstNoOriginalSamples
kGetAtomicInstNoKnobList = 1 << 2
kGetAtomicInstNoInstrumentInfo = 1 << 3
kGetAtomicInstOriginalKnobList = 1 << 4
kGetAtomicInstAllKnobs = 1 << 5
kSetAtomicInstKeepOriginalInstrument = 1 << 0
kSetAtomicInstShareAcrossParts = 1 << 1
kSetAtomicInstCallerTosses = 1 << 2
kSetAtomicInstCallerGuarantees = 1 << 3
kSetAtomicInstInterruptSafe = 1 << 4
kSetAtomicInstDontPreprocess = 1 << 7
kInstrumentNamesModifiable = 1
kInstrumentNamesBoth = 2
kGenericMusicComponentSubtype = FOUR_CHAR_CODE('gene')
kGenericMusicKnob = 1
kGenericMusicInstrumentKnob = 2
kGenericMusicDrumKnob = 3
kGenericMusicGlobalController = 4
kGenericMusicResFirst = 0
kGenericMusicResMiscStringList = 1
kGenericMusicResMiscLongList = 2
kGenericMusicResInstrumentList = 3
kGenericMusicResDrumList = 4
kGenericMusicResInstrumentKnobDescriptionList = 5
kGenericMusicResDrumKnobDescriptionList = 6
kGenericMusicResKnobDescriptionList = 7
kGenericMusicResBitsLongList = 8
kGenericMusicResModifiableInstrumentHW = 9
kGenericMusicResGMTranslation = 10
kGenericMusicResROMInstrumentData = 11
kGenericMusicResAboutPICT = 12
kGenericMusicResLast = 13
kGenericMusicMiscLongFirst = 0
kGenericMusicMiscLongVoiceCount = 1
kGenericMusicMiscLongPartCount = 2
kGenericMusicMiscLongModifiableInstrumentCount = 3
kGenericMusicMiscLongChannelMask = 4
kGenericMusicMiscLongDrumPartCount = 5
kGenericMusicMiscLongModifiableDrumCount = 6
kGenericMusicMiscLongDrumChannelMask = 7
kGenericMusicMiscLongOutputCount = 8
kGenericMusicMiscLongLatency = 9
kGenericMusicMiscLongFlags = 10
kGenericMusicMiscLongFirstGMHW = 11
kGenericMusicMiscLongFirstGMDrumHW = 12
kGenericMusicMiscLongFirstUserHW = 13
kGenericMusicMiscLongLast = 14
kMusicGenericRange = 0x0100
kMusicDerivedRange = 0x0200
kGenericMusicDoMIDI = 1 << 0
kGenericMusicBank0 = 1 << 1
kGenericMusicBank32 = 1 << 2
kGenericMusicErsatzMIDI = 1 << 3
kGenericMusicCallKnobs = 1 << 4
kGenericMusicCallParts = 1 << 5
kGenericMusicCallInstrument = 1 << 6
kGenericMusicCallNumber = 1 << 7
kGenericMusicCallROMInstrument = 1 << 8
kGenericMusicAllDefaults = 1 << 9
kGetInstrumentInfoNoBuiltIn = 1 << 0
kGetInstrumentInfoMidiUserInst = 1 << 1
kGetInstrumentInfoNoIText = 1 << 2
kNoteRequestNoGM = 1
kNoteRequestNoSynthType = 2
kNoteRequestSynthMustMatch = 4
kNoteRequestSpecifyMIDIChannel = 0x80
kPickDontMix = 1
kPickSameSynth = 2
kPickUserInsts = 4
kPickEditAllowEdit = 8
kPickEditAllowPick = 16
kPickEditSynthGlobal = 32
kPickEditControllers = 64
kNoteAllocatorComponentType = FOUR_CHAR_CODE('nota')
kNADummyOneSelect = 29
kNADummyTwoSelect = 30
kTuneQueueDepth = 8
kTunePlayerComponentType = FOUR_CHAR_CODE('tune')
kTuneStartNow = 1
kTuneDontClipNotes = 2
kTuneExcludeEdgeNotes = 4
kTuneQuickStart = 8
kTuneLoopUntil = 16
kTunePlayDifference = 32
kTunePlayConcurrent = 64
kTuneStartNewMaster = 16384
kTuneStopFade = 1
kTuneStopSustain = 2
kTuneStopInstant = 4
kTuneStopReleaseChannels = 8
kTuneMixMute = 1
kTuneMixSolo = 2
kRestEventType = 0x00000000
kNoteEventType = 0x00000001
kControlEventType = 0x00000002
kMarkerEventType = 0x00000003
kUndefined1EventType = 0x00000008
kXNoteEventType = 0x00000009
kXControlEventType = 0x0000000A
kKnobEventType = 0x0000000B
kUndefined2EventType = 0x0000000C
kUndefined3EventType = 0x0000000D
kUndefined4EventType = 0x0000000E
kGeneralEventType = 0x0000000F
kXEventLengthBits = 0x00000002
kGeneralEventLengthBits = 0x00000003
kEventLen = 1L
kXEventLen = 2L
kRestEventLen = kEventLen
kNoteEventLen = kEventLen
kControlEventLen = kEventLen
kMarkerEventLen = kEventLen
kXNoteEventLen = kXEventLen
kXControlEventLen = kXEventLen
kGeneralEventLen = kXEventLen
kEventLengthFieldPos = 30
kEventLengthFieldWidth = 2
kEventTypeFieldPos = 29
kEventTypeFieldWidth = 3
kXEventTypeFieldPos = 28
kXEventTypeFieldWidth = 4
kEventPartFieldPos = 24
kEventPartFieldWidth = 5
kXEventPartFieldPos = 16
kXEventPartFieldWidth = 12
kRestEventDurationFieldPos = 0
kRestEventDurationFieldWidth = 24
kRestEventDurationMax = ((1L << kRestEventDurationFieldWidth) - 1)
kNoteEventPitchFieldPos = 18
kNoteEventPitchFieldWidth = 6
kNoteEventPitchOffset = 32
kNoteEventVolumeFieldPos = 11
kNoteEventVolumeFieldWidth = 7
kNoteEventVolumeOffset = 0
kNoteEventDurationFieldPos = 0
kNoteEventDurationFieldWidth = 11
kNoteEventDurationMax = ((1L << kNoteEventDurationFieldWidth) - 1)
kXNoteEventPitchFieldPos = 0
kXNoteEventPitchFieldWidth = 16
kXNoteEventDurationFieldPos = 0
kXNoteEventDurationFieldWidth = 22
kXNoteEventDurationMax = ((1L << kXNoteEventDurationFieldWidth) - 1)
kXNoteEventVolumeFieldPos = 22
kXNoteEventVolumeFieldWidth = 7
kControlEventControllerFieldPos = 16
kControlEventControllerFieldWidth = 8
kControlEventValueFieldPos = 0
kControlEventValueFieldWidth = 16
kXControlEventControllerFieldPos = 0
kXControlEventControllerFieldWidth = 16
kXControlEventValueFieldPos = 0
kXControlEventValueFieldWidth = 16
kKnobEventValueHighFieldPos = 0
kKnobEventValueHighFieldWidth = 16
kKnobEventKnobFieldPos = 16
kKnobEventKnobFieldWidth = 14
kKnobEventValueLowFieldPos = 0
kKnobEventValueLowFieldWidth = 16
kMarkerEventSubtypeFieldPos = 16
kMarkerEventSubtypeFieldWidth = 8
kMarkerEventValueFieldPos = 0
kMarkerEventValueFieldWidth = 16
kGeneralEventSubtypeFieldPos = 16
kGeneralEventSubtypeFieldWidth = 14
kGeneralEventLengthFieldPos = 0
kGeneralEventLengthFieldWidth = 16
kEndMarkerValue = 0x00000060
kEndMarkerValue = 0x60000000
# _ext = qtma_EXT(*lP
# ulen = (_ext < 2) ? 1 : 2
# ulen = (unsigned short)qtma_EXT(*lP
# ulen = lP[1]
# _ext = qtma_EXT(*lP
# ulen = (_ext < 2) ? 1 : 2
# ulen = (unsigned short)qtma_EXT(*lP
# ulen = lP[-1]
# x = (kRestEventType << kEventTypeFieldPos)   \
# x = EndianU32_NtoB(x) )
# x = (kNoteEventType << kEventTypeFieldPos)  \
# x = EndianU32_NtoB(x) )
# x = (kControlEventType << kEventTypeFieldPos)           \
# x = EndianU32_NtoB(x) )
# x = (kMarkerEventType << kEventTypeFieldPos)    \
# x = EndianU32_NtoB(x) )
# w1 = (kXNoteEventType << kXEventTypeFieldPos)            \
# w1 = EndianU32_NtoB(w1)
# w2 = (kXEventLengthBits << kEventLengthFieldPos)        \
# w2 = EndianU32_NtoB(w2) )
# w1 = (kXControlEventType << kXEventTypeFieldPos)             \
# w1 = EndianU32_NtoB(w1)
# w2 = (kXEventLengthBits << kEventLengthFieldPos)             \
# w2 = EndianU32_NtoB(w2) )
# w1 = (kKnobEventType << kXEventTypeFieldPos)                 \
# w1 = EndianU32_NtoB(w1)
# w2 = (kXEventLengthBits << kEventLengthFieldPos)             \
# w2 = EndianU32_NtoB(w2) )
# w1 = (kGeneralEventType << kXEventTypeFieldPos)              \
# w1 = EndianU32_NtoB(w1)
# w2 = (kGeneralEventLengthBits << kEventLengthFieldPos)          \
# w2 = EndianU32_NtoB(w2) )
kGeneralEventNoteRequest = 1
kGeneralEventPartKey = 4
kGeneralEventTuneDifference = 5
kGeneralEventAtomicInstrument = 6
kGeneralEventKnob = 7
kGeneralEventMIDIChannel = 8
kGeneralEventPartChange = 9
kGeneralEventNoOp = 10
kGeneralEventUsedNotes = 11
kGeneralEventPartMix = 12
kMarkerEventEnd = 0
kMarkerEventBeat = 1
kMarkerEventTempo = 2
kCurrentlyNativeEndian = 1
kCurrentlyNotNativeEndian = 2
kQTMIDIGetMIDIPortsSelect = 0x0001
kQTMIDIUseSendPortSelect = 0x0002
kQTMIDISendMIDISelect = 0x0003
kMusicGetDescriptionSelect = 0x0001
kMusicGetPartSelect = 0x0002
kMusicSetPartSelect = 0x0003
kMusicSetPartInstrumentNumberSelect = 0x0004
kMusicGetPartInstrumentNumberSelect = 0x0005
kMusicStorePartInstrumentSelect = 0x0006
kMusicGetPartAtomicInstrumentSelect = 0x0009
kMusicSetPartAtomicInstrumentSelect = 0x000A
kMusicGetPartKnobSelect = 0x0010
kMusicSetPartKnobSelect = 0x0011
kMusicGetKnobSelect = 0x0012
kMusicSetKnobSelect = 0x0013
kMusicGetPartNameSelect = 0x0014
kMusicSetPartNameSelect = 0x0015
kMusicFindToneSelect = 0x0016
kMusicPlayNoteSelect = 0x0017
kMusicResetPartSelect = 0x0018
kMusicSetPartControllerSelect = 0x0019
kMusicGetPartControllerSelect = 0x001A
kMusicGetMIDIProcSelect = 0x001B
kMusicSetMIDIProcSelect = 0x001C
kMusicGetInstrumentNamesSelect = 0x001D
kMusicGetDrumNamesSelect = 0x001E
kMusicGetMasterTuneSelect = 0x001F
kMusicSetMasterTuneSelect = 0x0020
kMusicGetInstrumentAboutInfoSelect = 0x0022
kMusicGetDeviceConnectionSelect = 0x0023
kMusicUseDeviceConnectionSelect = 0x0024
kMusicGetKnobSettingStringsSelect = 0x0025
kMusicGetMIDIPortsSelect = 0x0026
kMusicSendMIDISelect = 0x0027
kMusicStartOfflineSelect = 0x0029
kMusicSetOfflineTimeToSelect = 0x002A
kMusicGetInstrumentKnobDescriptionSelect = 0x002B
kMusicGetDrumKnobDescriptionSelect = 0x002C
kMusicGetKnobDescriptionSelect = 0x002D
kMusicGetInfoTextSelect = 0x002E
kMusicGetInstrumentInfoSelect = 0x002F
kMusicTaskSelect = 0x0031
kMusicSetPartInstrumentNumberInterruptSafeSelect = 0x0032
kMusicSetPartSoundLocalizationSelect = 0x0033
kMusicGenericConfigureSelect = 0x0100
kMusicGenericGetPartSelect = 0x0101
kMusicGenericGetKnobListSelect = 0x0102
kMusicGenericSetResourceNumbersSelect = 0x0103
kMusicDerivedMIDISendSelect = 0x0200
kMusicDerivedSetKnobSelect = 0x0201
kMusicDerivedSetPartSelect = 0x0202
kMusicDerivedSetInstrumentSelect = 0x0203
kMusicDerivedSetPartInstrumentNumberSelect = 0x0204
kMusicDerivedSetMIDISelect = 0x0205
kMusicDerivedStorePartInstrumentSelect = 0x0206
kMusicDerivedOpenResFileSelect = 0x0207
kMusicDerivedCloseResFileSelect = 0x0208
kNARegisterMusicDeviceSelect = 0x0000
kNAUnregisterMusicDeviceSelect = 0x0001
kNAGetRegisteredMusicDeviceSelect = 0x0002
kNASaveMusicConfigurationSelect = 0x0003
kNANewNoteChannelSelect = 0x0004
kNADisposeNoteChannelSelect = 0x0005
kNAGetNoteChannelInfoSelect = 0x0006
kNAPrerollNoteChannelSelect = 0x0007
kNAUnrollNoteChannelSelect = 0x0008
kNASetNoteChannelVolumeSelect = 0x000B
kNAResetNoteChannelSelect = 0x000C
kNAPlayNoteSelect = 0x000D
kNASetControllerSelect = 0x000E
kNASetKnobSelect = 0x000F
kNAFindNoteChannelToneSelect = 0x0010
kNASetInstrumentNumberSelect = 0x0011
kNAPickInstrumentSelect = 0x0012
kNAPickArrangementSelect = 0x0013
kNAStuffToneDescriptionSelect = 0x001B
kNACopyrightDialogSelect = 0x001C
kNAGetIndNoteChannelSelect = 0x001F
kNAGetMIDIPortsSelect = 0x0021
kNAGetNoteRequestSelect = 0x0022
kNASendMIDISelect = 0x0023
kNAPickEditInstrumentSelect = 0x0024
kNANewNoteChannelFromAtomicInstrumentSelect = 0x0025
kNASetAtomicInstrumentSelect = 0x0026
kNAGetKnobSelect = 0x0028
kNATaskSelect = 0x0029
kNASetNoteChannelBalanceSelect = 0x002A
kNASetInstrumentNumberInterruptSafeSelect = 0x002B
kNASetNoteChannelSoundLocalizationSelect = 0x002C
kNAGetControllerSelect = 0x002D
kTuneSetHeaderSelect = 0x0004
kTuneGetTimeBaseSelect = 0x0005
kTuneSetTimeScaleSelect = 0x0006
kTuneGetTimeScaleSelect = 0x0007
kTuneGetIndexedNoteChannelSelect = 0x0008
kTuneQueueSelect = 0x000A
kTuneInstantSelect = 0x000B
kTuneGetStatusSelect = 0x000C
kTuneStopSelect = 0x000D
kTuneSetVolumeSelect = 0x0010
kTuneGetVolumeSelect = 0x0011
kTunePrerollSelect = 0x0012
kTuneUnrollSelect = 0x0013
kTuneSetNoteChannelsSelect = 0x0014
kTuneSetPartTransposeSelect = 0x0015
kTuneGetNoteAllocatorSelect = 0x0017
kTuneSetSofterSelect = 0x0018
kTuneTaskSelect = 0x0019
kTuneSetBalanceSelect = 0x001A
kTuneSetSoundLocalizationSelect = 0x001B
kTuneSetHeaderWithSizeSelect = 0x001C
kTuneSetPartMixSelect = 0x001D
kTuneGetPartMixSelect = 0x001E
